# 
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

import unittest, sys
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

  def test_145_BindRetrieveNoneEmptyString(self):
    obj = IbmDbTestFunctions()
    obj.assert_expect(self.run_test_145)

  def run_test_145(self):
    conn = ibm_db.connect(config.database, config.user, config.password)

    if conn:
      ibm_db.autocommit(conn, ibm_db.SQL_AUTOCOMMIT_OFF)

      stmt = ibm_db.prepare(conn, "INSERT INTO animals (id, breed, name) VALUES (?, ?, ?)")

      id = 999
      breed = None
      name = 'PythonDS'
      ibm_db.bind_param(stmt, 1, id)
      ibm_db.bind_param(stmt, 2, breed)
      ibm_db.bind_param(stmt, 3, name)

      # After this statement, we expect that the BREED column will contain
      # an SQL NULL value, while the NAME column contains an empty string

      ibm_db.execute(stmt)

      # After this statement, we expect that the BREED column will contain
      # an SQL NULL value, while the NAME column contains an empty string.
      # Use the dynamically bound parameters to ensure that the code paths
      # for both ibm_db.bind_param and ibm_db.execute treat Python Nones and empty
      # strings the right way.

      ibm_db.execute(stmt, (1000, None, 'PythonDS'))

      result = ibm_db.exec_immediate(conn, "SELECT id, breed, name FROM animals WHERE breed IS NULL")
      row = ibm_db.fetch_tuple(result)
      while ( row ): 
        for i in row:
          print i
        row = ibm_db.fetch_tuple(result)

      ibm_db.rollback(conn)
    else:
      print "Connection failed."

#__END__
#__LUW_EXPECTED__
#999
#None
#PythonDS        
#1000
#None
#PythonDS        
#__ZOS_EXPECTED__
#999
#None
#PythonDS        
#1000
#None
#PythonDS        
#__SYSTEMI_EXPECTED__
#999
#None
#PythonDS        
#1000
#None
#PythonDS        
#__IDS_EXPECTED__
#999
#None
#PythonDS        
#1000
#None
#PythonDS        



# 
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

import unittest, sys
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

  def test_240_FieldWidthPosName_01(self):
    obj = IbmDbTestFunctions()
    obj.assert_expect(self.run_test_240)

  def run_test_240(self):
    conn = ibm_db.connect(config.database, config.user, config.password)
    
    result = ibm_db.exec_immediate(conn, "select * from sales")
    result2 = ibm_db.exec_immediate(conn, "select * from staff")
    result3 = ibm_db.exec_immediate(conn, "select * from emp_photo")
    
    for i in range(0, ibm_db.num_fields(result)):
      print str(i) + ":" + str(ibm_db.field_width(result,i))
    
    print "\n-----"
    
    for i in range(0, ibm_db.num_fields(result2)):
      print str(i) + ":" + str(ibm_db.field_width(result2,ibm_db.field_name(result2,i)))
          
    print "\n-----"
    
    for i in range(0, 3):
      print str(i) + ":" + str(ibm_db.field_width(result3,i)) + "," + str(ibm_db.field_display_size(result3,i))
    
    print "\n-----"
    print "region:%s" % ibm_db.field_type(result,'region')
    
    print "5:%s" % ibm_db.field_type(result2,5)

#__END__
#__LUW_EXPECTED__
#0:10
#1:15
#2:15
#3:11
#
#-----
#0:6
#1:9
#2:6
#3:5
#4:6
#5:9
#6:9
#
#-----
#0:6,6
#1:10,10
#2:1048576,2097152
#
#-----
#region:False
#5:decimal
#__ZOS_EXPECTED__
#0:10
#1:15
#2:15
#3:11
#
#-----
#0:6
#1:9
#2:6
#3:5
#4:6
#5:9
#6:9
#
#-----
#0:6,6
#1:10,10
#2:1048576,2097152
#
#-----
#region:False
#5:decimal
#__SYSTEMI_EXPECTED__
#0:10
#1:15
#2:15
#3:11
#
#-----
#0:6
#1:9
#2:6
#3:5
#4:6
#5:9
#6:9
#
#-----
#0:6,6
#1:10,10
#2:1048576,2097152
#
#-----
#region:False
#5:decimal
#__IDS_EXPECTED__
#0:10
#1:15
#2:15
#3:11
#
#-----
#0:6
#1:9
#2:6
#3:5
#4:6
#5:9
#6:9
#
#-----
#0:6,6
#1:10,10
#2:2147483647,-2
#
#-----
#region:string
#5:decimal



# 
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

import unittest, sys
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

  def test_157a_FetchAssocWithoutScrollableCursorErr(self):
    obj = IbmDbTestFunctions()
    obj.assert_expect(self.run_test_157a)

  def run_test_157a(self):
    conn = ibm_db.connect(config.database, config.user, config.password)
    server = ibm_db.server_info( conn )

    print "Starting..."
    if conn:
      sql = "SELECT id, name, breed, weight FROM animals ORDER BY breed"
      result = ibm_db.exec_immediate(conn, sql)

      try:
          i = 2
          row = ibm_db.fetch_assoc(result, i)
          while ( row ):
              if (server.DBMS_NAME[0:3] == 'IDS'):
                print "%-5d %-16s %-32s %10s" % (row['id'], row['name'], row['breed'], row['weight'])
              else:
                print "%-5d %-16s %-32s %10s" % (row['ID'], row['NAME'], row['BREED'], row['WEIGHT'])
              i = i + 2
          row = ibm_db.fetch_assoc(result, i)
      except:
          print "SQLSTATE: %s" % ibm_db.stmt_error(result)
          print "Message: %s" % ibm_db.stmt_errormsg(result)
	
      print "DONE"

#__END__
#__LUW_EXPECTED__
#Starting...
#SQLSTATE: HY106
#Message: [IBM][CLI Driver] CLI0145E  Fetch type out of range. SQLSTATE=HY106 SQLCODE=-99999
#DONE
#__ZOS_EXPECTED__
#Starting...
#SQLSTATE: HY106
#Message: [IBM][CLI Driver] CLI0145E  Fetch type out of range. SQLSTATE=HY106 SQLCODE=-99999
#DONE
#__SYSTEMI_EXPECTED__
#Starting...
#SQLSTATE: HY106
#Message: [IBM][CLI Driver] CLI0145E  Fetch type out of range. SQLSTATE=HY106 SQLCODE=-99999
#DONE
#__IDS_EXPECTED__
#Starting...
#SQLSTATE: HY106
#Message: [IBM][CLI Driver] CLI0145E  Fetch type out of range. SQLSTATE=HY106 SQLCODE=-99999
#DONE



# 
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

import unittest, sys
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

  def test_241_FieldWidthPosName_02(self):
    obj = IbmDbTestFunctions()
    obj.assert_expect(self.run_test_241)

  def run_test_241(self):
    conn = ibm_db.connect(config.database, config.user, config.password)
    
    result = ibm_db.exec_immediate(conn, "select * from sales")
    result2 = ibm_db.exec_immediate(conn, "select * from staff")
    result3 = ibm_db.exec_immediate(conn, "select * from emp_photo")
    
    for i in range(0, ibm_db.num_fields(result)):
      print str(ibm_db.field_width(result,i))
    
    print "\n-----"
    
    for i in range(0, ibm_db.num_fields(result2)):
      print str(ibm_db.field_width(result2,ibm_db.field_name(result2,i)))

#__END__
#__LUW_EXPECTED__
#10
#15
#15
#11
#
#-----
#6
#9
#6
#5
#6
#9
#9
#__ZOS_EXPECTED__
#10
#15
#15
#11
#
#-----
#6
#9
#6
#5
#6
#9
#9
#__SYSTEMI_EXPECTED__
#10
#15
#15
#11
#
#-----
#6
#9
#6
#5
#6
#9
#9
#__IDS_EXPECTED__
#10
#15
#15
#11
#
#-----
#6
#9
#6
#5
#6
#9
#9



# 
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

import unittest, sys
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

  def test_151_FetchAssocSelect_02(self):
    obj = IbmDbTestFunctions()
    obj.assert_expect(self.run_test_151)

  def run_test_151(self):
    conn = ibm_db.connect(config.database, config.user, config.password)

    server = ibm_db.server_info( conn )
    if (server.DBMS_NAME[0:3] == 'IDS'):
      op = {ibm_db.ATTR_CASE: ibm_db.CASE_UPPER}
      ibm_db.set_option(conn, op, 0)
    
    result = ibm_db.exec_immediate(conn, "select * from sales")
    
    row = ibm_db.fetch_assoc(result)
    while ( row ):
      #printf("%-10s ",row['SALES_DATE'])
      #printf("%-15s ",row['SALES_PERSON'])
      #printf("%-15s ",row['REGION'])
      #printf("%4s",row['SALES'])
      #puts ""
      if (row['SALES'] == None):
        row['SALES'] = ''
      print "%-10s %-15s %-15s %4s" % (row['SALES_DATE'], row['SALES_PERSON'], row['REGION'], row['SALES'])
      row = ibm_db.fetch_assoc(result)

#__END__
#__LUW_EXPECTED__
#
#1995-12-31 LUCCHESSI       Ontario-South      1
#1995-12-31 LEE             Ontario-South      3
#1995-12-31 LEE             Quebec             1
#1995-12-31 LEE             Manitoba           2
#1995-12-31 GOUNOT          Quebec             1
#1996-03-29 LUCCHESSI       Ontario-South      3
#1996-03-29 LUCCHESSI       Quebec             1
#1996-03-29 LEE             Ontario-South      2
#1996-03-29 LEE             Ontario-North      2
#1996-03-29 LEE             Quebec             3
#1996-03-29 LEE             Manitoba           5
#1996-03-29 GOUNOT          Ontario-South      3
#1996-03-29 GOUNOT          Quebec             1
#1996-03-29 GOUNOT          Manitoba           7
#1996-03-30 LUCCHESSI       Ontario-South      1
#1996-03-30 LUCCHESSI       Quebec             2
#1996-03-30 LUCCHESSI       Manitoba           1
#1996-03-30 LEE             Ontario-South      7
#1996-03-30 LEE             Ontario-North      3
#1996-03-30 LEE             Quebec             7
#1996-03-30 LEE             Manitoba           4
#1996-03-30 GOUNOT          Ontario-South      2
#1996-03-30 GOUNOT          Quebec            18
#1996-03-30 GOUNOT          Manitoba           1
#1996-03-31 LUCCHESSI       Manitoba           1
#1996-03-31 LEE             Ontario-South     14
#1996-03-31 LEE             Ontario-North      3
#1996-03-31 LEE             Quebec             7
#1996-03-31 LEE             Manitoba           3
#1996-03-31 GOUNOT          Ontario-South      2
#1996-03-31 GOUNOT          Quebec             1
#1996-04-01 LUCCHESSI       Ontario-South      3
#1996-04-01 LUCCHESSI       Manitoba           1
#1996-04-01 LEE             Ontario-South      8
#1996-04-01 LEE             Ontario-North       
#1996-04-01 LEE             Quebec             8
#1996-04-01 LEE             Manitoba           9
#1996-04-01 GOUNOT          Ontario-South      3
#1996-04-01 GOUNOT          Ontario-North      1
#1996-04-01 GOUNOT          Quebec             3
#1996-04-01 GOUNOT          Manitoba           7
#__ZOS_EXPECTED__
#
#1995-12-31 LUCCHESSI       Ontario-South      1
#1995-12-31 LEE             Ontario-South      3
#1995-12-31 LEE             Quebec             1
#1995-12-31 LEE             Manitoba           2
#1995-12-31 GOUNOT          Quebec             1
#1996-03-29 LUCCHESSI       Ontario-South      3
#1996-03-29 LUCCHESSI       Quebec             1
#1996-03-29 LEE             Ontario-South      2
#1996-03-29 LEE             Ontario-North      2
#1996-03-29 LEE             Quebec             3
#1996-03-29 LEE             Manitoba           5
#1996-03-29 GOUNOT          Ontario-South      3
#1996-03-29 GOUNOT          Quebec             1
#1996-03-29 GOUNOT          Manitoba           7
#1996-03-30 LUCCHESSI       Ontario-South      1
#1996-03-30 LUCCHESSI       Quebec             2
#1996-03-30 LUCCHESSI       Manitoba           1
#1996-03-30 LEE             Ontario-South      7
#1996-03-30 LEE             Ontario-North      3
#1996-03-30 LEE             Quebec             7
#1996-03-30 LEE             Manitoba           4
#1996-03-30 GOUNOT          Ontario-South      2
#1996-03-30 GOUNOT          Quebec            18
#1996-03-30 GOUNOT          Manitoba           1
#1996-03-31 LUCCHESSI       Manitoba           1
#1996-03-31 LEE             Ontario-South     14
#1996-03-31 LEE             Ontario-North      3
#1996-03-31 LEE             Quebec             7
#1996-03-31 LEE             Manitoba           3
#1996-03-31 GOUNOT          Ontario-South      2
#1996-03-31 GOUNOT          Quebec             1
#1996-04-01 LUCCHESSI       Ontario-South      3
#1996-04-01 LUCCHESSI       Manitoba           1
#1996-04-01 LEE             Ontario-South      8
#1996-04-01 LEE             Ontario-North       
#1996-04-01 LEE             Quebec             8
#1996-04-01 LEE             Manitoba           9
#1996-04-01 GOUNOT          Ontario-South      3
#1996-04-01 GOUNOT          Ontario-North      1
#1996-04-01 GOUNOT          Quebec             3
#1996-04-01 GOUNOT          Manitoba           7
#__SYSTEMI_EXPECTED__
#
#1995-12-31 LUCCHESSI       Ontario-South      1
#1995-12-31 LEE             Ontario-South      3
#1995-12-31 LEE             Quebec             1
#1995-12-31 LEE             Manitoba           2
#1995-12-31 GOUNOT          Quebec             1
#1996-03-29 LUCCHESSI       Ontario-South      3
#1996-03-29 LUCCHESSI       Quebec             1
#1996-03-29 LEE             Ontario-South      2
#1996-03-29 LEE             Ontario-North      2
#1996-03-29 LEE             Quebec             3
#1996-03-29 LEE             Manitoba           5
#1996-03-29 GOUNOT          Ontario-South      3
#1996-03-29 GOUNOT          Quebec             1
#1996-03-29 GOUNOT          Manitoba           7
#1996-03-30 LUCCHESSI       Ontario-South      1
#1996-03-30 LUCCHESSI       Quebec             2
#1996-03-30 LUCCHESSI       Manitoba           1
#1996-03-30 LEE             Ontario-South      7
#1996-03-30 LEE             Ontario-North      3
#1996-03-30 LEE             Quebec             7
#1996-03-30 LEE             Manitoba           4
#1996-03-30 GOUNOT          Ontario-South      2
#1996-03-30 GOUNOT          Quebec            18
#1996-03-30 GOUNOT          Manitoba           1
#1996-03-31 LUCCHESSI       Manitoba           1
#1996-03-31 LEE             Ontario-South     14
#1996-03-31 LEE             Ontario-North      3
#1996-03-31 LEE             Quebec             7
#1996-03-31 LEE             Manitoba           3
#1996-03-31 GOUNOT          Ontario-South      2
#1996-03-31 GOUNOT          Quebec             1
#1996-04-01 LUCCHESSI       Ontario-South      3
#1996-04-01 LUCCHESSI       Manitoba           1
#1996-04-01 LEE             Ontario-South      8
#1996-04-01 LEE             Ontario-North       
#1996-04-01 LEE             Quebec             8
#1996-04-01 LEE             Manitoba           9
#1996-04-01 GOUNOT          Ontario-South      3
#1996-04-01 GOUNOT          Ontario-North      1
#1996-04-01 GOUNOT          Quebec             3
#1996-04-01 GOUNOT          Manitoba           7
#__IDS_EXPECTED__
#
#1995-12-31 LUCCHESSI       Ontario-South      1
#1995-12-31 LEE             Ontario-South      3
#1995-12-31 LEE             Quebec             1
#1995-12-31 LEE             Manitoba           2
#1995-12-31 GOUNOT          Quebec             1
#1996-03-29 LUCCHESSI       Ontario-South      3
#1996-03-29 LUCCHESSI       Quebec             1
#1996-03-29 LEE             Ontario-South      2
#1996-03-29 LEE             Ontario-North      2
#1996-03-29 LEE             Quebec             3
#1996-03-29 LEE             Manitoba           5
#1996-03-29 GOUNOT          Ontario-South      3
#1996-03-29 GOUNOT          Quebec             1
#1996-03-29 GOUNOT          Manitoba           7
#1996-03-30 LUCCHESSI       Ontario-South      1
#1996-03-30 LUCCHESSI       Quebec             2
#1996-03-30 LUCCHESSI       Manitoba           1
#1996-03-30 LEE             Ontario-South      7
#1996-03-30 LEE             Ontario-North      3
#1996-03-30 LEE             Quebec             7
#1996-03-30 LEE             Manitoba           4
#1996-03-30 GOUNOT          Ontario-South      2
#1996-03-30 GOUNOT          Quebec            18
#1996-03-30 GOUNOT          Manitoba           1
#1996-03-31 LUCCHESSI       Manitoba           1
#1996-03-31 LEE             Ontario-South     14
#1996-03-31 LEE             Ontario-North      3
#1996-03-31 LEE             Quebec             7
#1996-03-31 LEE             Manitoba           3
#1996-03-31 GOUNOT          Ontario-South      2
#1996-03-31 GOUNOT          Quebec             1
#1996-04-01 LUCCHESSI       Ontario-South      3
#1996-04-01 LUCCHESSI       Manitoba           1
#1996-04-01 LEE             Ontario-South      8
#1996-04-01 LEE             Ontario-North       
#1996-04-01 LEE             Quebec             8
#1996-04-01 LEE             Manitoba           9
#1996-04-01 GOUNOT          Ontario-South      3
#1996-04-01 GOUNOT          Ontario-North      1
#1996-04-01 GOUNOT          Quebec             3
#1996-04-01 GOUNOT          Manitoba           7



# 
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

import unittest, sys
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

  def test_046_FetchTupleMany_05(self):
    obj = IbmDbTestFunctions()
    obj.assert_expect(self.run_test_046)

  def run_test_046(self):
    conn = ibm_db.connect(config.database, config.user, config.password)

    server = ibm_db.server_info( conn )
    if (server.DBMS_NAME[0:3] == 'IDS'):
      result = ibm_db.exec_immediate(conn, "SELECT empno, photo_format, photo_format FROM emp_photo") 
    else:
      result = ibm_db.exec_immediate(conn, "SELECT empno, photo_format, length(picture) FROM emp_photo")
    row = ibm_db.fetch_tuple(result)
    while ( row ):
      if row[1] != 'xwd':
        print "<a href='test_046.php?EMPNO=%s&FORMAT=%s' target=_blank>%s - %s - %s bytes</a><br>" % (row[0], row[1], row[0], row[1], row[2])
      row = ibm_db.fetch_tuple(result)

#__END__
#__LUW_EXPECTED__
#<a href='test_046.php?EMPNO=000130&FORMAT=jpg' target=_blank>000130 - jpg - 15398 bytes</a><br>
#<a href='test_046.php?EMPNO=000130&FORMAT=png' target=_blank>000130 - png - 10291 bytes</a><br>
#<a href='test_046.php?EMPNO=000140&FORMAT=jpg' target=_blank>000140 - jpg - 15398 bytes</a><br>
#<a href='test_046.php?EMPNO=000140&FORMAT=png' target=_blank>000140 - png - 10291 bytes</a><br>
#<a href='test_046.php?EMPNO=000150&FORMAT=jpg' target=_blank>000150 - jpg - 15398 bytes</a><br>
#<a href='test_046.php?EMPNO=000150&FORMAT=png' target=_blank>000150 - png - 10291 bytes</a><br>
#<a href='test_046.php?EMPNO=000190&FORMAT=jpg' target=_blank>000190 - jpg - 15398 bytes</a><br>
#<a href='test_046.php?EMPNO=000190&FORMAT=png' target=_blank>000190 - png - 10291 bytes</a><br>
#__ZOS_EXPECTED__
#<a href='test_046.php?EMPNO=000130&FORMAT=jpg' target=_blank>000130 - jpg - 15398 bytes</a><br>
#<a href='test_046.php?EMPNO=000130&FORMAT=png' target=_blank>000130 - png - 10291 bytes</a><br>
#<a href='test_046.php?EMPNO=000140&FORMAT=jpg' target=_blank>000140 - jpg - 15398 bytes</a><br>
#<a href='test_046.php?EMPNO=000140&FORMAT=png' target=_blank>000140 - png - 10291 bytes</a><br>
#<a href='test_046.php?EMPNO=000150&FORMAT=jpg' target=_blank>000150 - jpg - 15398 bytes</a><br>
#<a href='test_046.php?EMPNO=000150&FORMAT=png' target=_blank>000150 - png - 10291 bytes</a><br>
#<a href='test_046.php?EMPNO=000190&FORMAT=jpg' target=_blank>000190 - jpg - 15398 bytes</a><br>
#<a href='test_046.php?EMPNO=000190&FORMAT=png' target=_blank>000190 - png - 10291 bytes</a><br>
#__SYSTEMI_EXPECTED__
#<a href='test_046.php?EMPNO=000130&FORMAT=jpg' target=_blank>000130 - jpg - 15398 bytes</a><br>
#<a href='test_046.php?EMPNO=000130&FORMAT=png' target=_blank>000130 - png - 10291 bytes</a><br>
#<a href='test_046.php?EMPNO=000140&FORMAT=jpg' target=_blank>000140 - jpg - 15398 bytes</a><br>
#<a href='test_046.php?EMPNO=000140&FORMAT=png' target=_blank>000140 - png - 10291 bytes</a><br>
#<a href='test_046.php?EMPNO=000150&FORMAT=jpg' target=_blank>000150 - jpg - 15398 bytes</a><br>
#<a href='test_046.php?EMPNO=000150&FORMAT=png' target=_blank>000150 - png - 10291 bytes</a><br>
#<a href='test_046.php?EMPNO=000190&FORMAT=jpg' target=_blank>000190 - jpg - 15398 bytes</a><br>
#<a href='test_046.php?EMPNO=000190&FORMAT=png' target=_blank>000190 - png - 10291 bytes</a><br>
#__IDS_EXPECTED__
#<a href='test_046.php?EMPNO=000130&FORMAT=jpg' target=_blank>000130 - jpg - jpg bytes</a><br>
#<a href='test_046.php?EMPNO=000130&FORMAT=png' target=_blank>000130 - png - png bytes</a><br>
#<a href='test_046.php?EMPNO=000140&FORMAT=jpg' target=_blank>000140 - jpg - jpg bytes</a><br>
#<a href='test_046.php?EMPNO=000140&FORMAT=png' target=_blank>000140 - png - png bytes</a><br>
#<a href='test_046.php?EMPNO=000150&FORMAT=jpg' target=_blank>000150 - jpg - jpg bytes</a><br>
#<a href='test_046.php?EMPNO=000150&FORMAT=png' target=_blank>000150 - png - png bytes</a><br>
#<a href='test_046.php?EMPNO=000190&FORMAT=jpg' target=_blank>000190 - jpg - jpg bytes</a><br>
#<a href='test_046.php?EMPNO=000190&FORMAT=png' target=_blank>000190 - png - png bytes</a><br>



# 
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

import unittest, sys
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

  def test_03a_ResultNonExistCol(self):
    obj = IbmDbTestFunctions()
    obj.assert_expect(self.run_test_03a)

  def run_test_03a(self):
    conn = ibm_db.connect(config.database, config.user, config.password)
    server = ibm_db.server_info( conn )

    if conn:
      stmt = ibm_db.exec_immediate(conn, "SELECT id, breed, name, weight FROM animals WHERE id = 0")
      
      while ( ibm_db.fetch_row(stmt) ):
         breed = ibm_db.result(stmt, 1)
         print "string(%d) \"%s\"" % (len(breed), breed)
         if (server.DBMS_NAME[0:3] == 'IDS'):
            name = ibm_db.result(stmt, "name")
         else:
            name = ibm_db.result(stmt, "NAME")
         print "string(%d) \"%s\"" % (len(name), name)
    
         # following field does not exist in result set
         if (server.DBMS_NAME[0:3] == 'IDS'):
           name = ibm_db.result(stmt, "passport")
         else:
           name = ibm_db.result(stmt, "PASSPORT")
         print name
      ibm_db.close(conn)
      
    else:
      print "Connection failed."

#__END__
#__LUW_EXPECTED__
#string(3) "cat"
#string(16) "Pook            "
#None
#__ZOS_EXPECTED__
#string(3) "cat"
#string(16) "Pook            "
#None
#__SYSTEMI_EXPECTED__
#string(3) "cat"
#string(16) "Pook            "
#None
#__IDS_EXPECTED__
#string(3) "cat"
#string(16) "Pook            "
#None



#
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

import unittest, sys
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

  def test_264_InsertRetrieveBIGINTTypeColumn(self):
    obj = IbmDbTestFunctions()
    obj.assert_expect(self.run_test_264)

  def run_test_264(self):
    # Make a connection
    conn = ibm_db.connect(config.database, config.user, config.password)

    if conn:
       server = ibm_db.server_info( conn )
       if (server.DBMS_NAME[0:3] == 'IDS'):
          op = {ibm_db.ATTR_CASE: ibm_db.CASE_UPPER}
          ibm_db.set_option(conn, op, 0)

       # Drop the tab_bigint table, in case it exists
       drop = 'DROP TABLE tab_bigint'
       result = ''
       try:
         result = ibm_db.exec_immediate(conn, drop)
       except:
         pass
       # Create the tab_bigint table
       if (server.DBMS_NAME[0:3] == 'IDS'):
          create = "CREATE TABLE tab_bigint (col1 INT8, col2 INT8, col3 INT8, col4 INT8)"
       else:
          create = "CREATE TABLE tab_bigint (col1 BIGINT, col2 BIGINT, col3 BIGINT, col4 BIGINT)"
       result = ibm_db.exec_immediate(conn, create)

       insert = "INSERT INTO tab_bigint values (-9223372036854775807, 9223372036854775807, 0, NULL)"
       res = ibm_db.exec_immediate(conn, insert)
       print "Number of inserted rows:", ibm_db.num_rows(res)

       stmt = ibm_db.prepare(conn, "SELECT * FROM tab_bigint")
       ibm_db.execute(stmt)
       data = ibm_db.fetch_both(stmt)
       while ( data ):
         print data[0]
         print data[1]
         print data[2]
         print data[3]
         print type(data[0]) is long
         print type(data[1]) is long 
         print type(data[2]) is long
         data = ibm_db.fetch_both(stmt)

       ibm_db.close(conn)

#__END__
#__LUW_EXPECTED__
#Number of inserted rows: 1
#-9223372036854775807
#9223372036854775807
#0
#None
#True
#True
#True
#__ZOS_EXPECTED__
#Number of inserted rows: 1
#-9223372036854775807
#9223372036854775807
#0
#None
#True
#True
#True
#__SYSTEMI_EXPECTED__
#Number of inserted rows: 1
#-9223372036854775807
#9223372036854775807
#0
#None
#True
#True
#True
#__IDS_EXPECTED__
#Number of inserted rows: 1
#-9223372036854775807
#9223372036854775807
#0
#None
#True
#True
#True



# 
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

import unittest, sys
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

  def test_142_BindParamSelectStmtMultipleParams_02(self):
    obj = IbmDbTestFunctions()
    obj.assert_expect(self.run_test_142)

  def run_test_142(self):
    sql = "SELECT id, breed, name, weight FROM animals WHERE weight < ? AND weight > ?"
    
    conn = ibm_db.connect(config.database, config.user, config.password)
    
    if conn:
      stmt = ibm_db.prepare(conn, sql)
    
      weight = 200.05
      mass = 2.0
      
      ibm_db.bind_param(stmt, 1, weight, ibm_db.SQL_PARAM_INPUT)
      ibm_db.bind_param(stmt, 2, mass, ibm_db.SQL_PARAM_INPUT)
    
      result = ibm_db.execute(stmt) 
      if ( result ):
        row = ibm_db.fetch_tuple(stmt)
        while ( row ):
          #row.each { |child| print child }
          for i in row:
            print i
          row = ibm_db.fetch_tuple(stmt)
      ibm_db.close(conn)
    else:
      print "Connection failed."

#__END__
#__LUW_EXPECTED__
#0
#cat
#Pook            
#3.20
#1
#dog
#Peaches         
#12.30
#5
#goat
#Rickety Ride    
#9.70
#6
#llama
#Sweater         
#150.00
#__ZOS_EXPECTED__
#0
#cat
#Pook            
#3.20
#1
#dog
#Peaches         
#12.30
#5
#goat
#Rickety Ride    
#9.70
#6
#llama
#Sweater         
#150.00
#__SYSTEMI_EXPECTED__
#0
#cat
#Pook            
#3.20
#1
#dog
#Peaches         
#12.30
#5
#goat
#Rickety Ride    
#9.70
#6
#llama
#Sweater         
#150.00
#__IDS_EXPECTED__
#0
#cat
#Pook            
#3.20
#1
#dog
#Peaches         
#12.30
#5
#goat
#Rickety Ride    
#9.70
#6
#llama
#Sweater         
#150.00



# 
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

import unittest, sys
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):
    def test_createdbNX(self):
        obj = IbmDbTestFunctions()
        obj.assert_expect(self.run_test_createdbNX)

    def run_test_createdbNX(self):
        database = 'test001'
        conn_str = "DATABASE=%s;HOSTNAME=%s;PORT=%d;PROTOCOL=TCPIP;UID=%s;PWD=%s;" % (database, config.hostname, config.port, config.user, config.password)
        conn_str_attach = "attach=true;HOSTNAME=%s;PORT=%d;PROTOCOL=TCPIP;UID=%s;PWD=%s;" % (config.hostname, config.port, config.user, config.password) #for create db or drop db API it is nessesory that connection only attach to the DB server not to any existing database of DB server
        conn_attach = ibm_db.connect(conn_str_attach, '', '')

        if conn_attach:
            conn = False
            try:
                conn = ibm_db.connect(conn_str, '', '')
            except:
                pass

            if conn:
                ibm_db.close(conn)
                conn = False
                try:
                    ibm_db.dropdb(conn_attach, database)
                except:
                    print 'Errors occurred during drop database'
            try:        
                # call createdbNX without  codeset argument when specified database not exeist   
                rc = ibm_db.createdbNX(conn_attach, database)
                if rc:
                    conn = ibm_db.connect(conn_str, '', '')
                    if conn:
                        print 'database created sucessfully'
                        ibm_db.close(conn)
                        conn = False
                    else:
                        print 'database is not created'
                else:
                    print 'Error occurred during create db if not exist'

                conn = ibm_db.connect(conn_str, '', '')
                if conn:
                    ibm_db.close(conn)
                    conn = False
                    # call recreate db with codeset argument when specified database  exist
                    rc = ibm_db.createdbNX(conn_attach, database, 'iso88591')
                    if rc:
                        conn = ibm_db.connect(conn_str, '', '')
                        server_info = ibm_db.server_info( conn )
                        if conn and (server_info.DB_CODEPAGE != 819):
                            print 'database with codeset created sucessfully'
                            ibm_db.close(conn)
                            conn = False
                        else:
                            print 'Database not created'
                    else:
                        print 'Error occurred during create db if not exist with codeset'
                        
                #drop database
                rc = ibm_db.dropdb(conn_attach, database)
                if rc:
                    try:
                        conn = ibm_db.connect(conn_str, '', '')
                    except:
                        print 'datbase droped sucessfully'
                    if conn:
                        print 'Errors occurred during drop database'
                        ibm_db.close(conn)
                        conn = False
                else:
                    print 'Errors occurred during drop database'
            except:
                print ibm_db.conn_errormsg()
                pass
            ibm_db.close(conn_attach)
        else:
            print ibm_db.conn_errormsg()
            
#__END__
#__LUW_EXPECTED__
#database created sucessfully
#database with codeset created sucessfully
#datbase droped sucessfully



#
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

import unittest, sys
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

  def test_053_AttrThruConn(self):
    obj = IbmDbTestFunctions()
    obj.assert_expect(self.run_test_053)

  def run_test_053(self):
    print "Client attributes passed through conection string:"

    options1 = {ibm_db.SQL_ATTR_INFO_USERID: 'db2inst1'}
    conn1 = ibm_db.connect(config.database, config.user, config.password, options1)
    val = ibm_db.get_option(conn1, ibm_db.SQL_ATTR_INFO_USERID, 1)
    print val

    options2 = {ibm_db.SQL_ATTR_INFO_ACCTSTR: 'account'}
    conn2 = ibm_db.connect(config.database, config.user, config.password, options2)
    val = ibm_db.get_option(conn2, ibm_db.SQL_ATTR_INFO_ACCTSTR, 1)
    print val

    options3 = {ibm_db.SQL_ATTR_INFO_APPLNAME: 'myapp'}
    conn3 = ibm_db.connect(config.database, config.user, config.password, options3)
    val = ibm_db.get_option(conn3, ibm_db.SQL_ATTR_INFO_APPLNAME, 1)
    print val

    options4 = {ibm_db.SQL_ATTR_INFO_WRKSTNNAME: 'workstation'}
    conn4 = ibm_db.connect(config.database, config.user, config.password, options4)
    val = ibm_db.get_option(conn4, ibm_db.SQL_ATTR_INFO_WRKSTNNAME, 1)
    print val

    options5 = {ibm_db.SQL_ATTR_INFO_USERID: 'kfb',
                ibm_db.SQL_ATTR_INFO_WRKSTNNAME: 'kfbwork',
                ibm_db.SQL_ATTR_INFO_ACCTSTR: 'kfbacc',
                ibm_db.SQL_ATTR_INFO_APPLNAME: 'kfbapp'}
    conn5 = ibm_db.connect(config.database, config.user, config.password, options5)
    val = ibm_db.get_option(conn5, ibm_db.SQL_ATTR_INFO_USERID, 1)
    print val
    val = ibm_db.get_option(conn5, ibm_db.SQL_ATTR_INFO_ACCTSTR, 1)
    print val
    val = ibm_db.get_option(conn5, ibm_db.SQL_ATTR_INFO_APPLNAME, 1)
    print val
    val = ibm_db.get_option(conn5, ibm_db.SQL_ATTR_INFO_WRKSTNNAME, 1)
    print val

    print "Client attributes passed post-conection:"

    options5 = {ibm_db.SQL_ATTR_INFO_USERID: 'db2inst1'}
    conn5 = ibm_db.connect(config.database, config.user, config.password)
    rc = ibm_db.set_option(conn5, options5, 1)
    val = ibm_db.get_option(conn5, ibm_db.SQL_ATTR_INFO_USERID, 1)
    print val

    options6 = {ibm_db.SQL_ATTR_INFO_ACCTSTR: 'account'}
    conn6 = ibm_db.connect(config.database, config.user, config.password)
    rc = ibm_db.set_option(conn6, options6, 1)
    val = ibm_db.get_option(conn6, ibm_db.SQL_ATTR_INFO_ACCTSTR, 1)
    print val

    options7 = {ibm_db.SQL_ATTR_INFO_APPLNAME: 'myapp'}
    conn7 = ibm_db.connect(config.database, config.user, config.password)
    rc = ibm_db.set_option(conn7, options7, 1)
    val = ibm_db.get_option(conn7, ibm_db.SQL_ATTR_INFO_APPLNAME, 1)
    print val

    options8 = {ibm_db.SQL_ATTR_INFO_WRKSTNNAME: 'workstation'}
    conn8 = ibm_db.connect(config.database, config.user, config.password)
    rc = ibm_db.set_option(conn8, options8, 1)
    val = ibm_db.get_option(conn8, ibm_db.SQL_ATTR_INFO_WRKSTNNAME, 1)
    print val

#__END__
#__LUW_EXPECTED__
#Client attributes passed through conection string:
#db2inst1
#account
#myapp
#workstation
#kfb
#kfbacc
#kfbapp
#kfbwork
#Client attributes passed post-conection:
#db2inst1
#account
#myapp
#workstation
#__ZOS_EXPECTED__
#Client attributes passed through conection string:
#db2inst1
#account
#myapp
#workstation
#kfb
#kfbacc
#kfbapp
#kfbwork
#Client attributes passed post-conection:
#db2inst1
#account
#myapp
#workstation
#__SYSTEMI_EXPECTED__
#Client attributes passed through conection string:
#db2inst1
#account
#myapp
#workstation
#kfb
#kfbacc
#kfbapp
#kfbwork
#Client attributes passed post-conection:
#db2inst1
#account
#myapp
#workstation
#__IDS_EXPECTED__
#Client attributes passed through conection string:
#db2inst1
#account
#myapp
#workstation
#kfb
#kfbacc
#kfbapp
#kfbwork
#Client attributes passed post-conection:
#db2inst1
#account
#myapp
#workstation



# 
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

import unittest, sys
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

  def test_310_ClientInfo(self):
    obj = IbmDbTestFunctions()
    obj.assert_expectf(self.run_test_310)

  def run_test_310(self):
    conn = ibm_db.connect(config.database, config.user, config.password)
    
    client = ibm_db.client_info(conn)
    
    if client:
      print "DRIVER_NAME: string(%d) \"%s\"" % (len(client.DRIVER_NAME), client.DRIVER_NAME)
      print "DRIVER_VER: string(%d) \"%s\"" % (len(client.DRIVER_VER), client.DRIVER_VER)
      print "DATA_SOURCE_NAME: string(%d) \"%s\"" % (len(client.DATA_SOURCE_NAME), client.DATA_SOURCE_NAME)
      print "DRIVER_ODBC_VER: string(%d) \"%s\"" % (len(client.DRIVER_ODBC_VER), client.DRIVER_ODBC_VER)
      print "ODBC_VER: string(%d) \"%s\"" % (len(client.ODBC_VER), client.ODBC_VER)
      print "ODBC_SQL_CONFORMANCE: string(%d) \"%s\"" % (len(client.ODBC_SQL_CONFORMANCE), client.ODBC_SQL_CONFORMANCE)
      print "APPL_CODEPAGE: int(%s)" % client.APPL_CODEPAGE
      print "CONN_CODEPAGE: int(%s)" % client.CONN_CODEPAGE
    
      ibm_db.close(conn)
    else:
      print "Error."

#__END__
#__LUW_EXPECTED__
#DRIVER_NAME: string(%d) %s
#DRIVER_VER: string(%d) %s
#DATA_SOURCE_NAME: string(%d) %s
#DRIVER_ODBC_VER: string(%d) %s
#ODBC_VER: string(%d) %s
#ODBC_SQL_CONFORMANCE: string(%d) %s
#APPL_CODEPAGE: int(%d)
#CONN_CODEPAGE: int(%d)
#__ZOS_EXPECTED__
#DRIVER_NAME: string(%d) %s
#DRIVER_VER: string(%d) %s
#DATA_SOURCE_NAME: string(%d) %s
#DRIVER_ODBC_VER: string(%d) %s
#ODBC_VER: string(%d) %s
#ODBC_SQL_CONFORMANCE: string(%d) %s
#APPL_CODEPAGE: int(%d)
#CONN_CODEPAGE: int(%d)
#__SYSTEMI_EXPECTED__
#DRIVER_NAME: string(%d) %s
#DRIVER_VER: string(%d) %s
#DATA_SOURCE_NAME: string(%d) %s
#DRIVER_ODBC_VER: string(%d) %s
#ODBC_VER: string(%d) %s
#ODBC_SQL_CONFORMANCE: string(%d) %s
#APPL_CODEPAGE: int(%d)
#CONN_CODEPAGE: int(%d)
#__IDS_EXPECTED__
#DRIVER_NAME: string(%d) %s
#DRIVER_VER: string(%d) %s
#DATA_SOURCE_NAME: string(%d) %s
#DRIVER_ODBC_VER: string(%d) %s
#ODBC_VER: string(%d) %s
#ODBC_SQL_CONFORMANCE: string(%d) %s
#APPL_CODEPAGE: int(%d)
#CONN_CODEPAGE: int(%d)



# 
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#
# NOTE: IDS does not support XML as a native datatype (test is invalid for IDS)

import unittest, sys
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

  def test_196_InsertRetrieveXMLData_02(self):
    obj = IbmDbTestFunctions()
    obj.assert_expectf(self.run_test_196)

  def run_test_196(self):
    conn = ibm_db.connect(config.database, config.user, config.password)
    server = ibm_db.server_info( conn )

    if ((server.DBMS_NAME[0:3] != 'IDS') and (server.DBMS_NAME[0:2] != "AS")):
      try:
          rc = ibm_db.exec_immediate(conn, "DROP TABLE xml_test")
      except:
          pass
      rc = ibm_db.exec_immediate(conn, "CREATE TABLE xml_test (id INTEGER, data VARCHAR(50), xmlcol XML)")
      rc = ibm_db.exec_immediate(conn, "INSERT INTO xml_test (id, data, xmlcol) values (1, 'xml test 1', '<address><street>12485 S Pine St.</street><city>Olathe</city><state>KS</state><zip>66061</zip></address>')")

      sql =  "SELECT * FROM xml_test"
      stmt = ibm_db.prepare(conn, sql)
      ibm_db.execute(stmt)
      result = ibm_db.fetch_both(stmt)
      while( result ):
        print "Result ID:", result[0]
        print "Result DATA:", result[1]
        print "Result XMLCOL:", result[2]
        result = ibm_db.fetch_both(stmt)

      sql = "SELECT XMLSERIALIZE(XMLQUERY('for $i in $t/address where $i/city = \"Olathe\" return <zip>{$i/zip/text()}</zip>' passing c.xmlcol as \"t\") AS CLOB(32k)) FROM xml_test c WHERE id = 1"
      stmt = ibm_db.prepare(conn, sql)
      ibm_db.execute(stmt)
      result = ibm_db.fetch_both(stmt)
      while( result ):
        print "Result from XMLSerialize and XMLQuery:", result[0]
        result = ibm_db.fetch_both(stmt)

      sql = "select xmlquery('for $i in $t/address where $i/city = \"Olathe\" return <zip>{$i/zip/text()}</zip>' passing c.xmlcol as \"t\") from xml_test c where id = 1"
      stmt = ibm_db.prepare(conn, sql)
      ibm_db.execute(stmt)
      result = ibm_db.fetch_both(stmt)
      while( result ):
        print "Result from only XMLQuery:", result[0]
        result = ibm_db.fetch_both(stmt)
    else:
      print 'Native XML datatype is not supported.'

#__END__
#__LUW_EXPECTED__
#Result ID: 1
#Result DATA: xml test 1
#Result XMLCOL:%s<address><street>12485 S Pine St.</street><city>Olathe</city><state>KS</state><zip>66061</zip></address>
#Result from XMLSerialize and XMLQuery: <zip>66061</zip>
#Result from only XMLQuery:%s<zip>66061</zip>
#__ZOS_EXPECTED__
#Result ID: 1
#Result DATA: xml test 1
#Result XMLCOL:%s<address><street>12485 S Pine St.</street><city>Olathe</city><state>KS</state><zip>66061</zip></address>
#Result from XMLSerialize and XMLQuery: <zip>66061</zip>
#Result from only XMLQuery:%s<zip>66061</zip>
#__SYSTEMI_EXPECTED__
#Native XML datatype is not supported.
#__IDS_EXPECTED__
#Native XML datatype is not supported.



# 
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

import unittest, sys
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

  def test_260_FetchTupleMany_07(self):
    obj = IbmDbTestFunctions() 
    obj.assert_expect(self.run_test_260)

  def run_test_260(self):
      conn = ibm_db.connect(config.database, config.user, config.password)
      
      if conn:
        stmt = ibm_db.exec_immediate(conn, "SELECT id, breed, name, weight FROM animals WHERE id = 0")
        
        row = ibm_db.fetch_tuple(stmt)
        while ( row ):
            for i in row:
                print i
            row = ibm_db.fetch_tuple(stmt)
        
        ibm_db.close(conn)
        
      else:
        print "Connection failed."

#__END__
#__LUW_EXPECTED__
#0
#cat
#Pook            
#3.20
#__ZOS_EXPECTED__
#0
#cat
#Pook            
#3.20
#__SYSTEMI_EXPECTED__
#0
#cat
#Pook            
#3.20
#__IDS_EXPECTED__
#0
#cat
#Pook            
#3.20



# 
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

import unittest, sys
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

  def test_120_FieldName(self):
    obj = IbmDbTestFunctions()
    obj.assert_expect(self.run_test_120)

  def run_test_120(self):
    conn = ibm_db.connect(config.database, config.user, config.password)
    server = ibm_db.server_info( conn )

    if conn:
      stmt = ibm_db.exec_immediate(conn, "SELECT * FROM animals")
    
      name1 = ibm_db.field_name(stmt, 1)
      name2 = ibm_db.field_name(stmt, 2)
      name3 = ibm_db.field_name(stmt, 3)
      name4 = ibm_db.field_name(stmt, 4)
      name6 = ibm_db.field_name(stmt, 8)
      name7 = ibm_db.field_name(stmt, 0)
      
      if (server.DBMS_NAME[0:3] == 'IDS'):
        name5 = ibm_db.field_name(stmt, "id")
        name8 = ibm_db.field_name(stmt, "WEIGHT")
      else:
        name5 = ibm_db.field_name(stmt, "ID")
        name8 = ibm_db.field_name(stmt, "weight")

      print "string(%d) \"%s\"" % (len(name1), name1)
      print "string(%d) \"%s\"" % (len(name2), name2)
      print "string(%d) \"%s\"" % (len(name3), name3)
      print "%s" % name4

      print "string(%d) \"%s\"" % (len(name5), name5)
      print "%s" % name6
      print "string(%d) \"%s\"" % (len(name7), name7)
      print "%s" % name8
    else:
      print "Connection failed."

#__END__
#__LUW_EXPECTED__
#string(5) "BREED"
#string(4) "NAME"
#string(6) "WEIGHT"
#False
#string(2) "ID"
#False
#string(2) "ID"
#False
#__ZOS_EXPECTED__
#string(5) "BREED"
#string(4) "NAME"
#string(6) "WEIGHT"
#False
#string(2) "ID"
#False
#string(2) "ID"
#False
#__SYSTEMI_EXPECTED__
#string(5) "BREED"
#string(4) "NAME"
#string(6) "WEIGHT"
#False
#string(2) "ID"
#False
#string(2) "ID"
#False
#__IDS_EXPECTED__
#string(5) "breed"
#string(4) "name"
#string(6) "weight"
#False
#string(2) "id"
#False
#string(2) "id"
#False



# 
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#
# NOTE: IDS requires that you pass the schema name (cannot pass None)

import unittest, sys
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

  def test_197_StatisticsIndexes(self):
    obj = IbmDbTestFunctions()
    obj.assert_expect(self.run_test_197)

  def run_test_197(self):
    conn = ibm_db.connect(config.database, config.user, config.password)
    server = ibm_db.server_info( conn )

    if conn:
      try:
          rc = ibm_db.exec_immediate(conn, "DROP TABLE index_test")
      except:
          pass
      rc = ibm_db.exec_immediate(conn, "CREATE TABLE index_test (id INTEGER, data VARCHAR(50))")
      rc = ibm_db.exec_immediate(conn, "CREATE UNIQUE INDEX index1 ON index_test (id)")

      print "Test first index table:"
      if (server.DBMS_NAME[0:3] == 'IDS'):
        result = ibm_db.statistics(conn,None,config.user,"index_test",True)
      else:
        result = ibm_db.statistics(conn,None,None,"INDEX_TEST",True)
      row = ibm_db.fetch_tuple(result)
      print row[2]  # TABLE_NAME
      print row[3]  # NON_UNIQUE
      print row[5]  # INDEX_NAME
      print row[8]  # COLUMN_NAME

      try:
          rc = ibm_db.exec_immediate(conn, "DROP TABLE index_test2")
      except:
          pass
      rc = ibm_db.exec_immediate(conn, "CREATE TABLE index_test2 (id INTEGER, data VARCHAR(50))")
      rc = ibm_db.exec_immediate(conn, "CREATE INDEX index2 ON index_test2 (data)")

      print "Test second index table:"
      if (server.DBMS_NAME[0:3] == 'IDS'):
        result = ibm_db.statistics(conn,None,config.user,"index_test2",True)
      else:
        result = ibm_db.statistics(conn,None,None,"INDEX_TEST2",True)
      row = ibm_db.fetch_tuple(result)
      print row[2]  # TABLE_NAME
      print row[3]  # NON_UNIQUE
      print row[5]  # INDEX_NAME
      print row[8]  # COLUMN_NAME

      print "Test non-existent table:"
      if (server.DBMS_NAME[0:3] == 'IDS'):
        result = ibm_db.statistics(conn,None,config.user,"non_existent_table",True)
      else:
        result = ibm_db.statistics(conn,None,None,"NON_EXISTENT_TABLE",True)
      row = ibm_db.fetch_tuple(result)
      if row:
        print "Non-Empty"
      else:
        print "Empty"
    else:
      print 'no connection: ' + ibm_db.conn_errormsg()

#__END__
#__LUW_EXPECTED__
#Test first index table:
#INDEX_TEST
#0
#INDEX1
#ID
#Test second index table:
#INDEX_TEST2
#1
#INDEX2
#DATA
#Test non-existent table:
#Empty
#__ZOS_EXPECTED__
#Test first index table:
#INDEX_TEST
#0
#INDEX1
#ID
#Test second index table:
#INDEX_TEST2
#1
#INDEX2
#DATA
#Test non-existent table:
#Empty
#__SYSTEMI_EXPECTED__
#Test first index table:
#INDEX_TEST
#0
#INDEX1
#ID
#Test second index table:
#INDEX_TEST2
#1
#INDEX2
#DATA
#Test non-existent table:
#Empty
#__IDS_EXPECTED__
#Test first index table:
#index_test
#0
#index1
#id
#Test second index table:
#index_test2
#1
#index2
#data
#Test non-existent table:
#Empty



# 
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

import unittest, sys
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

  def test_103_NumFieldsSelect_02(self):
    obj = IbmDbTestFunctions()
    obj.assert_expect(self.run_test_103)

  def run_test_103(self):
    conn = ibm_db.connect(config.database, config.user, config.password)
    
    if conn:
       result = ibm_db.exec_immediate(conn, "select * from org, project order by project.projname")
       cols = ibm_db.num_fields(result)
       j = 1
       row = ibm_db.fetch_tuple(result)
       while ( row ):
          print "%d) " % j
          for i in range(0, cols):
             print "%s " % row[i]
          j += 1
          if (j > 10):
             break
          row = ibm_db.fetch_tuple(result)
       ibm_db.close(conn)
    else:
      print ibm_db.conn_errormsg()

#__END__
#__LUW_EXPECTED__
#1) 10 Head Office 160 Corporate New York AD3113 ACCOUNT PROGRAMMING D21 000270 2.00 1982-01-01 1983-02-01 AD3110 
#2) 15 New England 50 Eastern Boston AD3113 ACCOUNT PROGRAMMING D21 000270 2.00 1982-01-01 1983-02-01 AD3110 
#3) 20 Mid Atlantic 10 Eastern Washington AD3113 ACCOUNT PROGRAMMING D21 000270 2.00 1982-01-01 1983-02-01 AD3110 
#4) 38 South Atlantic 30 Eastern Atlanta AD3113 ACCOUNT PROGRAMMING D21 000270 2.00 1982-01-01 1983-02-01 AD3110 
#5) 42 Great Lakes 100 Midwest Chicago AD3113 ACCOUNT PROGRAMMING D21 000270 2.00 1982-01-01 1983-02-01 AD3110 
#6) 51 Plains 140 Midwest Dallas AD3113 ACCOUNT PROGRAMMING D21 000270 2.00 1982-01-01 1983-02-01 AD3110 
#7) 66 Pacific 270 Western San Francisco AD3113 ACCOUNT PROGRAMMING D21 000270 2.00 1982-01-01 1983-02-01 AD3110 
#8) 84 Mountain 290 Western Denver AD3113 ACCOUNT PROGRAMMING D21 000270 2.00 1982-01-01 1983-02-01 AD3110 
#9) 10 Head Office 160 Corporate New York AD3100 ADMIN SERVICES D01 000010 6.50 1982-01-01 1983-02-01        
#10) 15 New England 50 Eastern Boston AD3100 ADMIN SERVICES D01 000010 6.50 1982-01-01 1983-02-01        
#__ZOS_EXPECTED__
#1) 84 Mountain 290 Western Denver AD3113 ACCOUNT PROGRAMMING D21 000270 2.00 1982-01-01 1983-02-01 AD3110 
#2) 66 Pacific 270 Western San Francisco AD3113 ACCOUNT PROGRAMMING D21 000270 2.00 1982-01-01 1983-02-01 AD3110 
#3) 51 Plains 140 Midwest Dallas AD3113 ACCOUNT PROGRAMMING D21 000270 2.00 1982-01-01 1983-02-01 AD3110 
#4) 42 Great Lakes 100 Midwest Chicago AD3113 ACCOUNT PROGRAMMING D21 000270 2.00 1982-01-01 1983-02-01 AD3110 
#5) 38 South Atlantic 30 Eastern Atlanta AD3113 ACCOUNT PROGRAMMING D21 000270 2.00 1982-01-01 1983-02-01 AD3110 
#6) 20 Mid Atlantic 10 Eastern Washington AD3113 ACCOUNT PROGRAMMING D21 000270 2.00 1982-01-01 1983-02-01 AD3110 
#7) 15 New England 50 Eastern Boston AD3113 ACCOUNT PROGRAMMING D21 000270 2.00 1982-01-01 1983-02-01 AD3110 
#8) 10 Head Office 160 Corporate New York AD3113 ACCOUNT PROGRAMMING D21 000270 2.00 1982-01-01 1983-02-01 AD3110 
#9) 84 Mountain 290 Western Denver AD3100 ADMIN SERVICES D01 000010 6.50 1982-01-01 1983-02-01        
#10) 66 Pacific 270 Western San Francisco AD3100 ADMIN SERVICES D01 000010 6.50 1982-01-01 1983-02-01        
#__SYSTEMI_EXPECTED__
#1) 10 Head Office 160 Corporate New York AD3113 ACCOUNT PROGRAMMING D21 000270 2.00 1982-01-01 1983-02-01 AD3110 
#2) 15 New England 50 Eastern Boston AD3113 ACCOUNT PROGRAMMING D21 000270 2.00 1982-01-01 1983-02-01 AD3110 
#3) 20 Mid Atlantic 10 Eastern Washington AD3113 ACCOUNT PROGRAMMING D21 000270 2.00 1982-01-01 1983-02-01 AD3110 
#4) 38 South Atlantic 30 Eastern Atlanta AD3113 ACCOUNT PROGRAMMING D21 000270 2.00 1982-01-01 1983-02-01 AD3110 
#5) 42 Great Lakes 100 Midwest Chicago AD3113 ACCOUNT PROGRAMMING D21 000270 2.00 1982-01-01 1983-02-01 AD3110 
#6) 51 Plains 140 Midwest Dallas AD3113 ACCOUNT PROGRAMMING D21 000270 2.00 1982-01-01 1983-02-01 AD3110 
#7) 66 Pacific 270 Western San Francisco AD3113 ACCOUNT PROGRAMMING D21 000270 2.00 1982-01-01 1983-02-01 AD3110 
#8) 84 Mountain 290 Western Denver AD3113 ACCOUNT PROGRAMMING D21 000270 2.00 1982-01-01 1983-02-01 AD3110 
#9) 10 Head Office 160 Corporate New York AD3100 ADMIN SERVICES D01 000010 6.50 1982-01-01 1983-02-01        
#10) 15 New England 50 Eastern Boston AD3100 ADMIN SERVICES D01 000010 6.50 1982-01-01 1983-02-01        
#__IDS_EXPECTED__
#1) 38 South Atlantic 30 Eastern Atlanta AD3113 ACCOUNT PROGRAMMING D21 000270 2.00 1982-01-01 1983-02-01 AD3110 
#2) 42 Great Lakes 100 Midwest Chicago AD3113 ACCOUNT PROGRAMMING D21 000270 2.00 1982-01-01 1983-02-01 AD3110 
#3) 10 Head Office 160 Corporate New York AD3113 ACCOUNT PROGRAMMING D21 000270 2.00 1982-01-01 1983-02-01 AD3110 
#4) 51 Plains 140 Midwest Dallas AD3113 ACCOUNT PROGRAMMING D21 000270 2.00 1982-01-01 1983-02-01 AD3110 
#5) 15 New England 50 Eastern Boston AD3113 ACCOUNT PROGRAMMING D21 000270 2.00 1982-01-01 1983-02-01 AD3110 
#6) 66 Pacific 270 Western San Francisco AD3113 ACCOUNT PROGRAMMING D21 000270 2.00 1982-01-01 1983-02-01 AD3110 
#7) 84 Mountain 290 Western Denver AD3113 ACCOUNT PROGRAMMING D21 000270 2.00 1982-01-01 1983-02-01 AD3110 
#8) 20 Mid Atlantic 10 Eastern Washington AD3113 ACCOUNT PROGRAMMING D21 000270 2.00 1982-01-01 1983-02-01 AD3110 
#9) 15 New England 50 Eastern Boston AD3100 ADMIN SERVICES D01 000010 6.50 1982-01-01 1983-02-01        
#10) 20 Mid Atlantic 10 Eastern Washington AD3100 ADMIN SERVICES D01 000010 6.50 1982-01-01 1983-02-01        



# 
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

import unittest, sys
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

  def test_102_NumFieldsSelect_01(self):
    obj = IbmDbTestFunctions()
    obj.assert_expect(self.run_test_102)

  def run_test_102(self):
    conn = ibm_db.connect(config.database, config.user, config.password)
    
    if (not conn):
      print ibm_db.conn_errormsg()
    
    server = ibm_db.server_info( conn )
    if ((server.DBMS_NAME[0:2] != "AS") and (server.DBMS_NAME != "DB2")):
      result = ibm_db.exec_immediate(conn, "VALUES(1)")
      #throw :unsupported unless result
      if (not result):
        raise Exception('Unsupported')
      print ibm_db.num_fields(result)
    else:
      print '1'
    ibm_db.close(conn)

#__END__
#__LUW_EXPECTED__
#1
#__ZOS_EXPECTED__
#1
#__SYSTEMI_EXPECTED__
#1
#__IDS_EXPECTED__
#1



# 
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

import unittest, sys
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

  def test_232_FieldTypePosName(self):
    obj = IbmDbTestFunctions()
    obj.assert_expect(self.run_test_232)

  def run_test_232(self):
    conn = ibm_db.connect(config.database, config.user, config.password)

    result = ibm_db.exec_immediate(conn, "select * from sales")
     
    for i in range(0, ibm_db.num_fields(result) + 1):
      field_name = ibm_db.field_name(result,i)
      field_type = ibm_db.field_type(result, ibm_db.field_name(result,i))
      print str(ibm_db.field_name(result, i)) + ":" + str(ibm_db.field_type(result, ibm_db.field_name(result, i)))
          
    print "-----"
    
    t = ibm_db.field_type(result,99)
    print t
    
    t1 = ibm_db.field_type(result, "HELMUT")
    print t1

#__END__
#__LUW_EXPECTED__
#SALES_DATE:date
#SALES_PERSON:string
#REGION:string
#SALES:int
#False:False
#-----
#False
#False
#__ZOS_EXPECTED__
#SALES_DATE:date
#SALES_PERSON:string
#REGION:string
#SALES:int
#False:False
#-----
#False
#False
#__SYSTEMI_EXPECTED__
#SALES_DATE:date
#SALES_PERSON:string
#REGION:string
#SALES:int
#False:False
#-----
#False
#False
#__IDS_EXPECTED__
#sales_date:date
#sales_person:string
#region:string
#sales:int
#False:False
#-----
#False
#False



# 
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

import unittest, sys
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

  def test_221_100PersistentConns(self):
    obj = IbmDbTestFunctions()
    obj.assert_expect(self.run_test_221)

  def run_test_221(self):
    pconn = range(100)
    
    for i in range(100):
      pconn[i] = ibm_db.pconnect(config.database, config.user, config.password)
    
    if pconn[33]:
      conn = pconn[22]
      ibm_db.autocommit(conn, ibm_db.SQL_AUTOCOMMIT_OFF)
      stmt = ibm_db.exec_immediate(pconn[33], "UPDATE animals SET name = 'flyweight' WHERE weight < 10.0")
      print "Number of affected rows:", ibm_db.num_rows( stmt )
      ibm_db.rollback(conn)
      ibm_db.close(pconn[33])
    else:
      print "Connection failed."

#__END__
#__LUW_EXPECTED__
#Number of affected rows: 4
#__ZOS_EXPECTED__
#Number of affected rows: 4
#__SYSTEMI_EXPECTED__
#Number of affected rows: 4
#__IDS_EXPECTED__
#Number of affected rows: 4



# 
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

import unittest, sys
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

  def test_112_FieldNumDiffCaseColNames(self):
    obj = IbmDbTestFunctions()
    obj.assert_expect(self.run_test_112)

  def run_test_112(self):
    conn = ibm_db.connect(config.database, config.user, config.password)

    if conn:
      drop = "DROP TABLE ftest"
      try:
        ibm_db.exec_immediate( conn, drop )
      except:
        pass
      
      create = "CREATE TABLE ftest ( \"TEST\" INTEGER, \"test\" INTEGER, \"Test\" INTEGER  )"
      ibm_db.exec_immediate(conn, create)
      
      insert = "INSERT INTO ftest VALUES (1,2,3)"
      ibm_db.exec_immediate(conn, insert)
      
      stmt = ibm_db.exec_immediate(conn, "SELECT * FROM ftest")
    
      num1 = ibm_db.field_num(stmt, "TEST")
      num2 = ibm_db.field_num(stmt, 'test')
      num3 = ibm_db.field_num(stmt, 'Test')
      
      print "int(%d)" % num1
      print "int(%d)" % num2
      print "int(%d)" % num3
      
    else:
      print "Connection failed."

#__END__
#__LUW_EXPECTED__
#int(0)
#int(1)
#int(2)
#__ZOS_EXPECTED__
#int(0)
#int(1)
#int(2)
#__SYSTEMI_EXPECTED__
#int(0)
#int(1)
#int(2)
#__IDS_EXPECTED__
#int(0)
#int(1)
#int(2)



# 
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

import unittest, sys
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

  def test_004_ConnWrongUserPwd(self):
    obj = IbmDbTestFunctions()
    obj.assert_expect(self.run_test_004)

  def run_test_004(self):
    try:
      conn = ibm_db.connect("sample", "not_a_user", "inv_pass")
    except:
      print "connect failed, test succeeded"
      return -1
    print "connect succeeded? Test failed"

#__END__
#__LUW_EXPECTED__
#connect failed, test succeeded
#__ZOS_EXPECTED__
#connect failed, test succeeded
#__SYSTEMI_EXPECTED__
#connect failed, test succeeded
#__IDS_EXPECTED__
#connect failed, test succeeded



# 
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

import unittest, sys
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

  def test_042_FetchTupleMany_02(self):
    obj = IbmDbTestFunctions()
    obj.assert_expect(self.run_test_042)

  def run_test_042(self):
    conn = ibm_db.connect(config.database, config.user, config.password)
      
    #if ({}['EMPNO'] != None):
    #  result = ibm_db.exec_immediate(conn, "select photo_format, picture, length(picture) from emp_photo where photo_format='jpg' and empno='" + {}['EMPNO'] + "'")
    #  row = ibm_db.fetch_array(result)
    #  if row:
    #    # We'll be outputting a         
    #    header('Content-type: image/' + row[0])
    #    header('Content-Length: ' + row[2])
    #    print row[1]
    #  else:
    #    print ibm_db.error()
    #  continue
    #else:
    result = ibm_db.exec_immediate(conn, "select EMPNO, PHOTO_FORMAT from emp_photo where photo_format='jpg'")
    row = ibm_db.fetch_tuple(result)
    while ( row ):
      print "<a href='test_042.php?EMPNO=%s' target=_blank>%s (%s)</a><br>" % (row[0], row[0], row[1])
      row = ibm_db.fetch_tuple(result)

#__END__
#__LUW_EXPECTED__
#<a href='test_042.php?EMPNO=000130' target=_blank>000130 (jpg)</a><br>
#<a href='test_042.php?EMPNO=000140' target=_blank>000140 (jpg)</a><br>
#<a href='test_042.php?EMPNO=000150' target=_blank>000150 (jpg)</a><br>
#<a href='test_042.php?EMPNO=000190' target=_blank>000190 (jpg)</a><br>
#__ZOS_EXPECTED__
#<a href='test_042.php?EMPNO=000130' target=_blank>000130 (jpg)</a><br>
#<a href='test_042.php?EMPNO=000140' target=_blank>000140 (jpg)</a><br>
#<a href='test_042.php?EMPNO=000150' target=_blank>000150 (jpg)</a><br>
#<a href='test_042.php?EMPNO=000190' target=_blank>000190 (jpg)</a><br>
#__SYSTEMI_EXPECTED__
#<a href='test_042.php?EMPNO=000130' target=_blank>000130 (jpg)</a><br>
#<a href='test_042.php?EMPNO=000140' target=_blank>000140 (jpg)</a><br>
#<a href='test_042.php?EMPNO=000150' target=_blank>000150 (jpg)</a><br>
#<a href='test_042.php?EMPNO=000190' target=_blank>000190 (jpg)</a><br>
#__IDS_EXPECTED__
#<a href='test_042.php?EMPNO=000130' target=_blank>000130 (jpg)</a><br>
#<a href='test_042.php?EMPNO=000140' target=_blank>000140 (jpg)</a><br>
#<a href='test_042.php?EMPNO=000150' target=_blank>000150 (jpg)</a><br>
#<a href='test_042.php?EMPNO=000190' target=_blank>000190 (jpg)</a><br>



# 
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

import unittest, sys
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

  def test_159_FetchAssocSeveralRows_01(self):
    obj = IbmDbTestFunctions()
    obj.assert_expect(self.run_test_159)

  def run_test_159(self):
    conn = ibm_db.connect(config.database, config.user, config.password)

    server = ibm_db.server_info( conn )
    if (server.DBMS_NAME[0:3] == 'IDS'):
      op = {ibm_db.ATTR_CASE: ibm_db.CASE_UPPER}
      ibm_db.set_option(conn, op, 0)

    result = ibm_db.exec_immediate(conn, "select name,job from staff")
    i = 1
    row = ibm_db.fetch_assoc(result)
    while ( row ):
      #printf("%3d %10s %10s\n",i, row['NAME'], row['JOB'])
      print "%3d %10s %10s" % (i, row['NAME'], row['JOB'])
      i += 1
      row = ibm_db.fetch_assoc(result)

#__END__
#__LUW_EXPECTED__
#  1    Sanders      Mgr  
#  2     Pernal      Sales
#  3   Marenghi      Mgr  
#  4     OBrien      Sales
#  5      Hanes      Mgr  
#  6    Quigley      Sales
#  7    Rothman      Sales
#  8      James      Clerk
#  9    Koonitz      Sales
# 10      Plotz      Mgr  
# 11       Ngan      Clerk
# 12   Naughton      Clerk
# 13  Yamaguchi      Clerk
# 14      Fraye      Mgr  
# 15   Williams      Sales
# 16   Molinare      Mgr  
# 17   Kermisch      Clerk
# 18   Abrahams      Clerk
# 19    Sneider      Clerk
# 20   Scoutten      Clerk
# 21         Lu      Mgr  
# 22      Smith      Sales
# 23  Lundquist      Clerk
# 24    Daniels      Mgr  
# 25    Wheeler      Clerk
# 26      Jones      Mgr  
# 27        Lea      Mgr  
# 28     Wilson      Sales
# 29      Quill      Mgr  
# 30      Davis      Sales
# 31     Graham      Sales
# 32   Gonzales      Sales
# 33      Burke      Clerk
# 34    Edwards      Sales
# 35     Gafney      Clerk
#__ZOS_EXPECTED__
#  1    Sanders      Mgr  
#  2     Pernal      Sales
#  3   Marenghi      Mgr  
#  4     OBrien      Sales
#  5      Hanes      Mgr  
#  6    Quigley      Sales
#  7    Rothman      Sales
#  8      James      Clerk
#  9    Koonitz      Sales
# 10      Plotz      Mgr  
# 11       Ngan      Clerk
# 12   Naughton      Clerk
# 13  Yamaguchi      Clerk
# 14      Fraye      Mgr  
# 15   Williams      Sales
# 16   Molinare      Mgr  
# 17   Kermisch      Clerk
# 18   Abrahams      Clerk
# 19    Sneider      Clerk
# 20   Scoutten      Clerk
# 21         Lu      Mgr  
# 22      Smith      Sales
# 23  Lundquist      Clerk
# 24    Daniels      Mgr  
# 25    Wheeler      Clerk
# 26      Jones      Mgr  
# 27        Lea      Mgr  
# 28     Wilson      Sales
# 29      Quill      Mgr  
# 30      Davis      Sales
# 31     Graham      Sales
# 32   Gonzales      Sales
# 33      Burke      Clerk
# 34    Edwards      Sales
# 35     Gafney      Clerk
#__SYSTEMI_EXPECTED__
#  1    Sanders      Mgr  
#  2     Pernal      Sales
#  3   Marenghi      Mgr  
#  4     OBrien      Sales
#  5      Hanes      Mgr  
#  6    Quigley      Sales
#  7    Rothman      Sales
#  8      James      Clerk
#  9    Koonitz      Sales
# 10      Plotz      Mgr  
# 11       Ngan      Clerk
# 12   Naughton      Clerk
# 13  Yamaguchi      Clerk
# 14      Fraye      Mgr  
# 15   Williams      Sales
# 16   Molinare      Mgr  
# 17   Kermisch      Clerk
# 18   Abrahams      Clerk
# 19    Sneider      Clerk
# 20   Scoutten      Clerk
# 21         Lu      Mgr  
# 22      Smith      Sales
# 23  Lundquist      Clerk
# 24    Daniels      Mgr  
# 25    Wheeler      Clerk
# 26      Jones      Mgr  
# 27        Lea      Mgr  
# 28     Wilson      Sales
# 29      Quill      Mgr  
# 30      Davis      Sales
# 31     Graham      Sales
# 32   Gonzales      Sales
# 33      Burke      Clerk
# 34    Edwards      Sales
# 35     Gafney      Clerk
#__IDS_EXPECTED__
#  1    Sanders      Mgr  
#  2     Pernal      Sales
#  3   Marenghi      Mgr  
#  4     OBrien      Sales
#  5      Hanes      Mgr  
#  6    Quigley      Sales
#  7    Rothman      Sales
#  8      James      Clerk
#  9    Koonitz      Sales
# 10      Plotz      Mgr  
# 11       Ngan      Clerk
# 12   Naughton      Clerk
# 13  Yamaguchi      Clerk
# 14      Fraye      Mgr  
# 15   Williams      Sales
# 16   Molinare      Mgr  
# 17   Kermisch      Clerk
# 18   Abrahams      Clerk
# 19    Sneider      Clerk
# 20   Scoutten      Clerk
# 21         Lu      Mgr  
# 22      Smith      Sales
# 23  Lundquist      Clerk
# 24    Daniels      Mgr  
# 25    Wheeler      Clerk
# 26      Jones      Mgr  
# 27        Lea      Mgr  
# 28     Wilson      Sales
# 29      Quill      Mgr  
# 30      Davis      Sales
# 31     Graham      Sales
# 32   Gonzales      Sales
# 33      Burke      Clerk
# 34    Edwards      Sales
# 35     Gafney      Clerk



# 
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

import unittest, sys
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

  def test_143_BindParamInsertStmtNoneParam(self):
    obj = IbmDbTestFunctions()
    obj.assert_expect(self.run_test_143)

  def run_test_143(self):
    conn = ibm_db.connect(config.database, config.user, config.password)
    
    ibm_db.autocommit(conn, ibm_db.SQL_AUTOCOMMIT_OFF)

    insert1 = "INSERT INTO animals (id, breed, name, weight) VALUES (NULL, 'ghost', NULL, ?)"
    select = 'SELECT id, breed, name, weight FROM animals WHERE weight IS NULL'
    
    if conn:
      stmt = ibm_db.prepare(conn, insert1)
    
      animal = None
      ibm_db.bind_param(stmt, 1, animal)
    
      if ibm_db.execute(stmt):
        stmt = ibm_db.exec_immediate(conn, select)
        row = ibm_db.fetch_tuple(stmt)
        while ( row ):
          #row.each { |child| print child }
          for i in row:
            print i
          row = ibm_db.fetch_tuple(stmt)

      ibm_db.rollback(conn)
    else:
      print "Connection failed."

#__END__
#__LUW_EXPECTED__
#None
#ghost
#None
#None
#__ZOS_EXPECTED__
#None
#ghost
#None
#None
#__SYSTEMI_EXPECTED__
#None
#ghost
#None
#None
#__IDS_EXPECTED__
#None
#ghost
#None
#None



# 
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

import unittest, sys
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

  def test_022_RollbackInsert(self):
    obj = IbmDbTestFunctions()
    obj.assert_expect(self.run_test_022)

  def run_test_022(self):
    conn = ibm_db.connect(config.database, config.user, config.password)
      
    if conn:
      stmt = ibm_db.exec_immediate(conn, "SELECT count(*) FROM animals")
      res = ibm_db.fetch_tuple(stmt)
      rows = res[0]
      print rows
        
      ibm_db.autocommit(conn, 0)
      ac = ibm_db.autocommit(conn)
      if ac != 0:
        print "Cannot set ibm_db.AUTOCOMMIT_OFF\nCannot run test"
        #continue
        
      ibm_db.exec_immediate(conn, "INSERT INTO animals values (7,'bug','Brain Bug',10000.1)")
        
      stmt = ibm_db.exec_immediate(conn, "SELECT count(*) FROM animals")
      res = ibm_db.fetch_tuple(stmt)
      rows = res[0]
      print rows
        
      ibm_db.rollback(conn)
      
      stmt = ibm_db.exec_immediate(conn, "SELECT count(*) FROM animals")
      res = ibm_db.fetch_tuple(stmt)
      rows = res[0]
      print rows
      ibm_db.close(conn)
    else:
      print "Connection failed."

#__END__
#__LUW_EXPECTED__
#7
#8
#7
#__ZOS_EXPECTED__
#7
#8
#7
#__SYSTEMI_EXPECTED__
#7
#8
#7
#__IDS_EXPECTED__
#7
#8
#7



# 
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

import unittest, sys
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

  def test_251_FreeResult_02(self):
    obj = IbmDbTestFunctions()
    obj.assert_expect(self.run_test_251)

  def run_test_251(self):
    conn = ibm_db.connect(config.database, config.user, config.password)
    
    result = ibm_db.exec_immediate(conn, "select * from sales")
    
    r1 = ibm_db.free_result(result)
    r2 = ibm_db.free_result(result)
    r3 = ''
    try:
      r3 = ibm_db.free_result(result99)
    except:
      r3 = None
    
    print r1
    print r2
    print r3

#__END__
#__LUW_EXPECTED__
#True
#True
#None
#__ZOS_EXPECTED__
#True
#True
#None
#__SYSTEMI_EXPECTED__
#True
#True
#None
#__IDS_EXPECTED__
#True
#True
#None



#
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

import unittest, sys
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

  def test_045_FetchTupleBinaryData_01(self):
    obj = IbmDbTestFunctions()
    obj.assert_expect(self.run_test_045)
    
  def run_test_045(self):
    conn = ibm_db.connect(config.database, config.user, config.password)
    fp = open("tests/pic1_out.jpg", "wb")
    result = ibm_db.exec_immediate(conn, "SELECT picture FROM animal_pics WHERE name = 'Helmut'")
    row = ibm_db.fetch_tuple(result)
    if row:
      fp.write(row[0])
    else:
      print ibm_db.stmt_errormsg()
    fp.close()
    cmp = (open('tests/pic1_out.jpg', 'rb').read() == open('tests/pic1.jpg', 'rb').read())
    print 'Are the files the same:', cmp


#__END__
#__LUW_EXPECTED__
#Are the files the same: True
#__ZOS_EXPECTED__
#Are the files the same: True
#__SYSTEMI_EXPECTED__
#Are the files the same: True
#__IDS_EXPECTED__
#Are the files the same: True



# 
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

import unittest, sys
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

  def test_002_ConnDbUncatalogedConn(self):
    obj = IbmDbTestFunctions()
    obj.assert_expect(self.run_test_002)

  def run_test_002(self):
    conn_str = "DATABASE=%s;HOSTNAME=%s;PORT=%d;PROTOCOL=TCPIP;UID=%s;PWD=%s;" % (config.database, config.hostname, config.port, config.user, config.password)
    conn = ibm_db.connect(conn_str, '', '')
      
    if conn:
      print "Connection succeeded."
      ibm_db.close(conn)
    else:
      print "Connection failed."

#__END__
#__LUW_EXPECTED__
#Connection succeeded.
#__ZOS_EXPECTED__
#Connection succeeded.
#__SYSTEMI_EXPECTED__
#Connection succeeded.
#__IDS_EXPECTED__
#Connection succeeded.



# 
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

import unittest, sys
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

  def test_6561_InsertNULLValues(self):
    obj = IbmDbTestFunctions()
    obj.assert_expect(self.run_test_6561)

  def run_test_6561(self):
    conn = ibm_db.connect(config.database, config.user, config.password)
    
    if conn:
      ibm_db.autocommit(conn, ibm_db.SQL_AUTOCOMMIT_OFF)

      stmt = ibm_db.exec_immediate(conn, "INSERT INTO animals (id, breed, name, weight) VALUES (null, null, null, null)")
      statement = "SELECT count(id) FROM animals"
      result = ibm_db.exec_immediate(conn, statement)
      if ( (not result) and ibm_db.stmt_error() ):
        print "ERROR: %s" % (ibm_db.stmt_errormsg(), )

      row = ibm_db.fetch_tuple(result)
      while ( row ):
        for i in row:
            print i
        row = ibm_db.fetch_tuple(result)
    
      ibm_db.rollback(conn)
      ibm_db.close(conn)
      
    else:
      print "Connection failed."

#__END__
#__LUW_EXPECTED__
#7
#__ZOS_EXPECTED__
#7
#__SYSTEMI_EXPECTED__
#7
#__IDS_EXPECTED__
#7



# 
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

import unittest, sys
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

  def test_125_FieldNamePos_03(self):
    obj = IbmDbTestFunctions()
    obj.assert_expect(self.run_test_125)

  def run_test_125(self):
    conn = ibm_db.connect(config.database, config.user, config.password)
    server = ibm_db.server_info( conn )

    result = ibm_db.exec_immediate(conn, "SELECT * FROM sales")
    result2 = ibm_db.exec_immediate(conn, "SELECT * FROM staff")
    
    for i in range(0, ibm_db.num_fields(result)):
      print "%d:%s" % (i, ibm_db.field_name(result,i))
    
    print "-----"
    
    for i in range(0, ibm_db.num_fields(result2)):
      print "%d:%s" % (i, ibm_db.field_name(result2,i))
    
    print "-----"
    
    if (server.DBMS_NAME[0:3] == 'IDS'):
      print "Region:%s" % ibm_db.field_name(result, 'region')
    else:
      print "Region:%s" % ibm_db.field_name(result, 'REGION')
    print "5:%s" % ibm_db.field_name(result2, 5)

#__END__
#__LUW_EXPECTED__
#0:SALES_DATE
#1:SALES_PERSON
#2:REGION
#3:SALES
#
#-----
#0:ID
#1:NAME
#2:DEPT
#3:JOB
#4:YEARS
#5:SALARY
#6:COMM
#
#-----
#Region:REGION
#5:SALARY
#__ZOS_EXPECTED__
#0:SALES_DATE
#1:SALES_PERSON
#2:REGION
#3:SALES
#
#-----
#0:ID
#1:NAME
#2:DEPT
#3:JOB
#4:YEARS
#5:SALARY
#6:COMM
#
#-----
#Region:REGION
#5:SALARY
#__SYSTEMI_EXPECTED__
#0:SALES_DATE
#1:SALES_PERSON
#2:REGION
#3:SALES
#
#-----
#0:ID
#1:NAME
#2:DEPT
#3:JOB
#4:YEARS
#5:SALARY
#6:COMM
#
#-----
#Region:REGION
#5:SALARY
#__IDS_EXPECTED__
#0:sales_date
#1:sales_person
#2:region
#3:sales
#
#-----
#0:id
#1:name
#2:dept
#3:job
#4:years
#5:salary
#6:comm
#
#-----
#Region:region
#5:salary



# 
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

import unittest, sys
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

  def test_6528_ScopingProblemBindParam(self):
    obj = IbmDbTestFunctions()
    obj.assert_expect(self.run_test_6528)

  def checked_db2_execute(self, stmt):
    ibm_db.execute(stmt)
    row = ibm_db.fetch_tuple(stmt)
    for i in row:
      print i
     
  def run_test_6528(self):
    conn = ibm_db.connect(config.database, config.user, config.password)
    server = ibm_db.server_info( conn )
    
    if conn:
      if (server.DBMS_NAME[0:3] == 'IDS'):
        sql = "SELECT TRIM(TRAILING FROM name) FROM animals WHERE breed = ?"
      else:
        sql = "SELECT RTRIM(name) FROM animals WHERE breed = ?"
      stmt = ibm_db.prepare(conn, sql)
      var = "cat"
      ibm_db.bind_param(stmt, 1, var, ibm_db.SQL_PARAM_INPUT)
      self.checked_db2_execute(stmt)
      ibm_db.close(conn)
    else:
      print "Connection failed."

#__END__
#__LUW_EXPECTED__
#Pook
#__ZOS_EXPECTED__
#Pook
#__SYSTEMI_EXPECTED__
#Pook
#__IDS_EXPECTED__
#Pook



#
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

import unittest, sys
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

  def test_311_InsertSelectDeleteNumLiterals(self):
    obj = IbmDbTestFunctions()
    obj.assert_expect(self.run_test_311)

  def run_test_311(self):
    # Make a connection
    conn = ibm_db.connect(config.database, config.user, config.password)

    if conn:
       ibm_db.autocommit(conn, ibm_db.SQL_AUTOCOMMIT_ON )

       # Drop the tab_num_literals table, in case it exists
       drop = 'DROP TABLE tab_num_literals'
       result = ''
       try:
         result = ibm_db.exec_immediate(conn, drop)
       except:
         pass
       # Create the animal table
       create = "CREATE TABLE tab_num_literals (col1 INTEGER, col2 FLOAT, col3 DECIMAL(7,2))"
       result = ibm_db.exec_immediate(conn, create)
   
       insert = "INSERT INTO tab_num_literals values ('11.22', '33.44', '55.66')"
       res = ibm_db.exec_immediate(conn, insert)
       print "Number of inserted rows:", ibm_db.num_rows(res)

       stmt = ibm_db.prepare(conn, "SELECT col1, col2, col3 FROM tab_num_literals WHERE col1 = '11'")
       ibm_db.execute(stmt)
       data = ibm_db.fetch_both(stmt)
       while ( data ):
         print data[0]
         print data[1]
         print data[2]
         data = ibm_db.fetch_both(stmt)

       sql = "UPDATE tab_num_literals SET col1 = 77 WHERE col2 = 33.44"
       res = ibm_db.exec_immediate(conn, sql)
       print "Number of updated rows:", ibm_db.num_rows(res)

       stmt = ibm_db.prepare(conn, "SELECT col1, col2, col3 FROM tab_num_literals WHERE col2 > '33'")
       ibm_db.execute(stmt)
       data = ibm_db.fetch_both(stmt)
       while ( data ):
         print data[0]
         print data[1]
         print data[2]
         data = ibm_db.fetch_both(stmt)
	 
       sql = "DELETE FROM tab_num_literals WHERE col1 > '10.0'"
       res = ibm_db.exec_immediate(conn, sql)
       print "Number of deleted rows:", ibm_db.num_rows(res)

       stmt = ibm_db.prepare(conn, "SELECT col1, col2, col3 FROM tab_num_literals WHERE col3 < '56'")
       ibm_db.execute(stmt)
       data = ibm_db.fetch_both(stmt)
       while ( data ):
         print data[0]
         print data[1]
         print data[2]
         data = ibm_db.fetch_both(stmt)

       ibm_db.rollback(conn)
       ibm_db.close(conn)

#__END__
#__LUW_EXPECTED__
#Number of inserted rows: 1
#11
#33.44
#55.66
#Number of updated rows: 1
#77
#33.44
#55.66
#Number of deleted rows: 1
#__ZOS_EXPECTED__
#Number of inserted rows: 1
#11
#33.44
#55.66
#Number of updated rows: 1
#77
#33.44
#55.66
#Number of deleted rows: 1
#__SYSTEMI_EXPECTED__
#Number of inserted rows: 1
#11
#33.44
#55.66
#Number of updated rows: 1
#77
#33.44
#55.66
#Number of deleted rows: 1
#__IDS_EXPECTED__
#Number of inserted rows: 1
#11
#33.44
#55.66
#Number of updated rows: 1
#77
#33.44
#55.66
#Number of deleted rows: 1



# 
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

import unittest, sys
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

  def test_033_ResultOutSequenceColumn(self):
    obj = IbmDbTestFunctions()
    obj.assert_expect(self.run_test_033)
	  
  def run_test_033(self): 
    conn = ibm_db.connect(config.database, config.user, config.password)
    server = ibm_db.server_info( conn )
      
    if conn:
      stmt = ibm_db.exec_immediate(conn, "SELECT id, breed, name, weight FROM animals WHERE id = 0")
        
      while (ibm_db.fetch_row(stmt)):
        weight = ibm_db.result(stmt, 3)
        print "string(%d) \"%s\"" % (len(str(weight)), weight)
        breed = ibm_db.result(stmt, 1)
        print "string(%d) \"%s\"" % (len(breed), breed)
        if (server.DBMS_NAME[0:3] == 'IDS'):
          name = ibm_db.result(stmt, "name")
        else:
          name = ibm_db.result(stmt, "NAME")
        print "string(%d) \"%s\"" % (len(name), name)
      ibm_db.close(conn)
    else:
      print "Connection failed."

#__END__
#__LUW_EXPECTED__
#string(4) "3.20"
#string(3) "cat"
#string(16) "Pook            "
#__ZOS_EXPECTED__
#string(4) "3.20"
#string(3) "cat"
#string(16) "Pook            "
#__SYSTEMI_EXPECTED__
#string(4) "3.20"
#string(3) "cat"
#string(16) "Pook            "
#__IDS_EXPECTED__
#string(4) "3.20"
#string(3) "cat"
#string(16) "Pook            "



# 
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

import unittest, sys
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

  def test_018_selectRowcountPrefetchSetOpt(self):
    obj = IbmDbTestFunctions()
    obj.assert_expect(self.run_test_018)

  def run_test_018(self):
    conn = ibm_db.connect(config.database, config.user, config.password)
    ibm_db.autocommit(conn, ibm_db.SQL_AUTOCOMMIT_ON)
    if conn:
      stmt = ibm_db.prepare(conn, "SELECT * from animals WHERE weight < 10.0" )
      ibm_db.set_option(stmt, {ibm_db.SQL_ATTR_ROWCOUNT_PREFETCH : ibm_db.SQL_ROWCOUNT_PREFETCH_ON}, 2)
      result = ibm_db.execute(stmt)
      if result:
        rows = ibm_db.num_rows(stmt)
        print "affected row:", rows
        ibm_db.free_result(stmt)
      else:
        print ibm_db.stmt_errormsg()

      ibm_db.set_option(stmt, {ibm_db.SQL_ATTR_ROWCOUNT_PREFETCH : ibm_db.SQL_ROWCOUNT_PREFETCH_OFF}, 2)
      result = ibm_db.execute(stmt)
      if result:
        rows = ibm_db.num_rows(stmt)
        print "affected row:", rows
        ibm_db.free_result(stmt)
      else:
        print ibm_db.stmt_errormsg()

      ibm_db.set_option(stmt, {ibm_db.SQL_ATTR_ROWCOUNT_PREFETCH : ibm_db.SQL_ROWCOUNT_PREFETCH_ON}, 2)
      result = ibm_db.execute(stmt)
      if result:
        rows = ibm_db.num_rows(stmt)
        print "affected row:", rows
      else:
        print ibm_db.stmt_errormsg()

      ibm_db.close(conn)
    else:
      print "no connection:", ibm_db.conn_errormsg()

#__END__
#__LUW_EXPECTED__
#affected row: 4
#affected row: -1
#affected row: 4
#__ZOS_EXPECTED__
#affected row: 4
#affected row: -1
#affected row: 4
#__SYSTEMI_EXPECTED__
#affected row: 4
#affected row: -1
#affected row: 4
#__IDS_EXPECTED__
#affected row: 4
#affected row: -1
#affected row: 4



# 
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

import unittest, sys
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):
  
  def test_007_pConnPassingOpts(self):
    obj = IbmDbTestFunctions()
    obj.assert_expect(self.run_test_007)

  def run_test_007(self):
    options1 = {ibm_db.SQL_ATTR_CURSOR_TYPE: ibm_db.SQL_CURSOR_KEYSET_DRIVEN}
    options2 = {ibm_db.SQL_ATTR_CURSOR_TYPE: ibm_db.SQL_CURSOR_FORWARD_ONLY}
      
    conn = ibm_db.pconnect(config.database, config.user, config.password)
      
    if conn:
      serverinfo = ibm_db.server_info( conn )
      if (serverinfo.DBMS_NAME[0:3] == 'IDS'):
        options1 = options2

      stmt = ibm_db.prepare(conn, "SELECT name FROM animals WHERE weight < 10.0", options2)
      ibm_db.execute(stmt)
      data = ibm_db.fetch_both(stmt)
      while ( data ):
        print data[0].strip()
        data = ibm_db.fetch_both(stmt)

      print ""
      
      stmt = ibm_db.prepare(conn, "SELECT name FROM animals WHERE weight < 10.0", options1)
      ibm_db.execute(stmt)
      data = ibm_db.fetch_both(stmt)
      while ( data ):
        print data[0].strip()
        data = ibm_db.fetch_both(stmt)
    
      ibm_db.close(conn)
    else:
      print "Connection failed."

#__END__
#__LUW_EXPECTED__
#Pook
#Bubbles
#Gizmo
#Rickety Ride
#
#Pook
#Bubbles
#Gizmo
#Rickety Ride
#__ZOS_EXPECTED__
#Pook
#Bubbles
#Gizmo
#Rickety Ride
#
#Pook
#Bubbles
#Gizmo
#Rickety Ride
#__SYSTEMI_EXPECTED__
#Pook
#Bubbles
#Gizmo
#Rickety Ride
#
#Pook
#Bubbles
#Gizmo
#Rickety Ride
#__IDS_EXPECTED__
#Pook
#Bubbles
#Gizmo
#Rickety Ride
#
#Pook
#Bubbles
#Gizmo
#Rickety Ride



# 
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

import unittest, sys
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

  def test_212_FieldDisplaySize_03(self):
    obj = IbmDbTestFunctions()
    obj.assert_expect(self.run_test_212)

  def run_test_212(self):
    conn = ibm_db.connect(config.database, config.user, config.password)
    server = ibm_db.server_info( conn )

    result = ibm_db.exec_immediate(conn, "select * from sales")
    
    if (server.DBMS_NAME[0:3] == 'IDS'):
      i = "sales_person"
    else:
      i = "SALES_PERSON"
    
    print "%s size %d" % (i, ibm_db.field_display_size(result,i))
    
    i = 2
    print "%d size %d" % (i, ibm_db.field_display_size(result,i))

#__END__
#__LUW_EXPECTED__
#SALES_PERSON size 15
#2 size 15
#__ZOS_EXPECTED__
#SALES_PERSON size 15
#2 size 15
#__SYSTEMI_EXPECTED__
#SALES_PERSON size 15
#2 size 15
#__IDS_EXPECTED__
#sales_person size 15
#2 size 15



# 
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

import unittest, sys, os
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

  def test_144_BindParamInsertStmtPARAM_FILE(self):
    obj = IbmDbTestFunctions()
    obj.assert_expect(self.run_test_144)

  def run_test_144(self):
    conn = ibm_db.connect(config.database, config.user, config.password)
    
    if conn:
      # Drop the test table, in case it exists
      drop = 'DROP TABLE pictures'
      try:
        result = ibm_db.exec_immediate(conn, drop)
      except:
        pass
      
      # Create the test table
      create = 'CREATE TABLE pictures (id INTEGER, picture BLOB)'
      result = ibm_db.exec_immediate(conn, create)
      
      stmt = ibm_db.prepare(conn, "INSERT INTO pictures VALUES (0, ?)")
      
      picture = os.path.dirname(os.path.abspath(__file__)) + "/pic1.jpg"
      rc = ibm_db.bind_param(stmt, 1, picture, ibm_db.SQL_PARAM_INPUT, ibm_db.SQL_BINARY)
    
      rc = ibm_db.execute(stmt)
      
      num = ibm_db.num_rows(stmt)
      
      print num
    else:
      print "Connection failed."

#__END__
#__LUW_EXPECTED__
#1
#__ZOS_EXPECTED__
#1
#__SYSTEMI_EXPECTED__
#1
#__IDS_EXPECTED__
#1



# 
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

import unittest, sys
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

  def test_157b_FetchAssocScrollableCursor_02(self):
    obj = IbmDbTestFunctions()
    obj.assert_expect(self.run_test_157b)

  def run_test_157b(self):
    conn = ibm_db.connect(config.database, config.user, config.password)
    server = ibm_db.server_info( conn )

    if conn:
      sql = "SELECT id, name, breed, weight FROM animals ORDER BY breed"
      if (server.DBMS_NAME[0:3] != 'IDS'):
        stmt = ibm_db.prepare(conn, sql, {ibm_db.SQL_ATTR_CURSOR_TYPE: ibm_db.SQL_CURSOR_KEYSET_DRIVEN})
      else:
        stmt = ibm_db.prepare(conn, sql, {ibm_db.SQL_ATTR_CURSOR_TYPE: ibm_db.SQL_CURSOR_STATIC})
      result = ibm_db.execute(stmt)
      i = 2
      row = ibm_db.fetch_assoc(stmt, i)
      while ( row ):
        if (server.DBMS_NAME[0:3] == 'IDS'):
          #printf("%-5d %-16s %-32s %10s\n", row['id'], row['name'], row['breed'], row['weight'])
          print "%-5d %-16s %-32s %10s" % (row['id'], row['name'], row['breed'], row['weight'])
        else:
          #printf("%-5d %-16s %-32s %10s\n", row['ID'], row['NAME'], row['BREED'], row['WEIGHT'])
          print "%-5d %-16s %-32s %10s" % (row['ID'], row['NAME'], row['BREED'], row['WEIGHT'])
        i = i + 2
        row = ibm_db.fetch_assoc(stmt, i)

#__END__
#__LUW_EXPECTED__
#0     Pook             cat                                    3.20
#5     Rickety Ride     goat                                   9.70
#2     Smarty           horse                                350.00
#__ZOS_EXPECTED__
#0     Pook             cat                                    3.20
#5     Rickety Ride     goat                                   9.70
#2     Smarty           horse                                350.00
#__SYSTEMI_EXPECTED__
#0     Pook             cat                                    3.20
#5     Rickety Ride     goat                                   9.70
#2     Smarty           horse                                350.00
#__IDS_EXPECTED__
#0     Pook             cat                                    3.20
#5     Rickety Ride     goat                                   9.70
#2     Smarty           horse                                350.00



# 
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

import unittest, sys
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

  def test_153_FetchAssocSelect_04(self):
    obj = IbmDbTestFunctions()
    obj.assert_expect(self.run_test_153)

  def run_test_153(self):
    conn = ibm_db.connect(config.database, config.user, config.password)

    server = ibm_db.server_info( conn )
    if (server.DBMS_NAME[0:3] == 'IDS'):
      op = {ibm_db.ATTR_CASE: ibm_db.CASE_UPPER}
      ibm_db.set_option(conn, op, 0)
    
    result = ibm_db.exec_immediate(conn, "select * from org")
    
    row = ibm_db.fetch_assoc(result)
    while ( row ):
      #printf("%4d ",row['DEPTNUMB'])
      #printf("%-14s ",row['DEPTNAME'])
      #printf("%4d ",row['MANAGER'])
      #printf("%-10s",row['DIVISION'])
      #printf("%-13s ",row['LOCATION'])
      #puts ""
      print "%4d %-14s %4d %-10s%-13s " % (row['DEPTNUMB'], row['DEPTNAME'], row['MANAGER'], row['DIVISION'], row['LOCATION'])
      row = ibm_db.fetch_assoc(result)

#__END__
#__LUW_EXPECTED__
#
#  10 Head Office     160 Corporate New York      
#  15 New England      50 Eastern   Boston        
#  20 Mid Atlantic     10 Eastern   Washington    
#  38 South Atlantic   30 Eastern   Atlanta       
#  42 Great Lakes     100 Midwest   Chicago       
#  51 Plains          140 Midwest   Dallas        
#  66 Pacific         270 Western   San Francisco 
#  84 Mountain        290 Western   Denver        
#__ZOS_EXPECTED__
#
#  10 Head Office     160 Corporate New York      
#  15 New England      50 Eastern   Boston        
#  20 Mid Atlantic     10 Eastern   Washington    
#  38 South Atlantic   30 Eastern   Atlanta       
#  42 Great Lakes     100 Midwest   Chicago       
#  51 Plains          140 Midwest   Dallas        
#  66 Pacific         270 Western   San Francisco 
#  84 Mountain        290 Western   Denver        
#__SYSTEMI_EXPECTED__
#
#  10 Head Office     160 Corporate New York      
#  15 New England      50 Eastern   Boston        
#  20 Mid Atlantic     10 Eastern   Washington    
#  38 South Atlantic   30 Eastern   Atlanta       
#  42 Great Lakes     100 Midwest   Chicago       
#  51 Plains          140 Midwest   Dallas        
#  66 Pacific         270 Western   San Francisco 
#  84 Mountain        290 Western   Denver        
#__IDS_EXPECTED__
#
#  10 Head Office     160 Corporate New York      
#  15 New England      50 Eastern   Boston        
#  20 Mid Atlantic     10 Eastern   Washington    
#  38 South Atlantic   30 Eastern   Atlanta       
#  42 Great Lakes     100 Midwest   Chicago       
#  51 Plains          140 Midwest   Dallas        
#  66 Pacific         270 Western   San Francisco 
#  84 Mountain        290 Western   Denver        
#



# 
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

import unittest, sys
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

  def test_52949_TestSPIntVarcharXml(self):
    obj = IbmDbTestFunctions()
    obj.assert_expect(self.run_test_52949)

  def test_int(self, conn):
    return_value = 0
    stmt, return_value = ibm_db.callproc(conn, 'PROCESSINT', (return_value,))
    print "ProcessINT:", return_value

  def test_varchar(self, conn):
    return_value = ""
    stmt, return_value = ibm_db.callproc(conn, 'PROCESSVAR', (return_value,))
    print "ProcessVAR:", return_value

  def test_xml(self, conn):
    return_value = "This is just a test for XML Column. The data gets truncated since we do not "
    stmt, return_value = ibm_db.callproc(conn, 'PROCESSXML', (return_value,))
    print "ProcessXML:", return_value.__str__()
    
  def drop_tables(self, conn):
    if conn:
     dr = "DROP PROCEDURE processxml"
     try:
       ibm_db.exec_immediate(conn, dr)
     except:
       pass
     try:
       dr = "DROP PROCEDURE processint"
       ibm_db.exec_immediate(conn, dr)
     except:
       pass
     try:
       dr = "DROP PROCEDURE processvar"
       ibm_db.exec_immediate(conn, dr)
     except:
       pass
     try:
       dr = "DROP TABLE test_stored"
       ibm_db.exec_immediate(conn, dr)
     except:
       pass

  def run_test_52949(self):
   conn = ibm_db.connect(config.database, config.user, config.password)

   if conn:
     serverinfo = ibm_db.server_info(conn )
     server = serverinfo.DBMS_NAME[0:3]
     result = ''
     self.drop_tables(conn)

     try:
       cr1 = "CREATE TABLE test_stored (id INT, name VARCHAR(50), age int, cv XML)"
       result = ibm_db.exec_immediate(conn, cr1)
       in1 = "INSERT INTO test_stored values (1, 'Kellen', 24, '<example>This is an example</example>')"
       result = ibm_db.exec_immediate(conn, in1)
       st1 = "CREATE PROCEDURE processxml(OUT risorsa xml) LANGUAGE SQL BEGIN SELECT cv INTO risorsa FROM test_stored WHERE ID = 1; END"
       result = ibm_db.exec_immediate(conn, st1)

       #self.test_xml(conn)
     except:
       pass
   
     try:
       self.drop_tables(conn)
       cr1 = "CREATE TABLE test_stored (id INT, name VARCHAR(50), age int, cv VARCHAR(200))"
       result = ibm_db.exec_immediate(conn, cr1)
       in1 = "INSERT INTO test_stored values (1, 'Kellen', 24, '<example>This is an example</example>')"
       result = ibm_db.exec_immediate(conn, in1)
     except:
       pass

     if (server == 'IDS'):
        st2 = "CREATE PROCEDURE processint(OUT risorsa int); SELECT age INTO risorsa FROM test_stored WHERE ID = 1; END PROCEDURE;"
     else:
        st2 = "CREATE PROCEDURE processint(OUT risorsa int) LANGUAGE SQL BEGIN SELECT age INTO risorsa FROM test_stored WHERE ID = 1; END"
     result = ibm_db.exec_immediate(conn, st2)
     
     if (server == 'IDS'):
        st3 = "CREATE PROCEDURE processvar(OUT risorsa varchar(50)); SELECT name INTO risorsa FROM test_stored WHERE ID = 1; END PROCEDURE;"
     else:
        st3 = "CREATE PROCEDURE processvar(OUT risorsa varchar(50)) LANGUAGE SQL BEGIN SELECT name INTO risorsa FROM test_stored WHERE ID = 1; END"
     result = ibm_db.exec_immediate(conn, st3)

     self.test_int(conn)
     self.test_varchar(conn)

     ibm_db.close(conn)
   else:
     print "Connection failed."

#__END__
#__LUW_EXPECTED__
#ProcessINT: 24
#ProcessVAR: Kellen
#__ZOS_EXPECTED__
#ProcessINT: 24
#ProcessVAR: Kellen
#__SYSTEMI_EXPECTED__
#ProcessINT: 24
#ProcessVAR: Kellen
#__IDS_EXPECTED__
#ProcessINT: 24
#ProcessVAR: Kellen



# 
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

import unittest, sys
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

  def test_001_ConnDb(self):
    obj = IbmDbTestFunctions()
    obj.assert_expect(self.run_test_001)

  def run_test_001(self):
    conn = ibm_db.connect(config.database, config.user, config.password)
      
    if conn:
      print "Connection succeeded."
      ibm_db.close(conn)
    else:
      print "Connection failed."

#__END__
#__LUW_EXPECTED__
#Connection succeeded.
#__ZOS_EXPECTED__
#Connection succeeded.
#__SYSTEMI_EXPECTED__
#Connection succeeded.
#__IDS_EXPECTED__
#Connection succeeded.



# 
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

import unittest, sys
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

  def test_041_FetchTupleMany_01(self):
    obj = IbmDbTestFunctions()
    obj.assert_expect(self.run_test_041)

  def run_test_041(self):
    conn = ibm_db.connect(config.database, config.user, config.password)
      
    if conn:
      stmt = ibm_db.exec_immediate(conn, "select * from animals order by breed")
      
      i = 0
      
      cols = ibm_db.fetch_tuple( stmt )
      while( cols ):
        print "%s %s %s %s " % (cols[0], cols[1], cols[2], cols[3])
        i+=1
        cols = ibm_db.fetch_tuple( stmt )
      
      print "\nNumber of rows: %d" % i
    else:
      print "Connection failed."

#__END__
#__LUW_EXPECTED__
#4 budgerigar Gizmo            0.20 
#0 cat Pook             3.20 
#1 dog Peaches          12.30 
#5 goat Rickety Ride     9.70 
#3 gold fish Bubbles          0.10 
#2 horse Smarty           350.00 
#6 llama Sweater          150.00 
#
#Number of rows: 7
#__ZOS_EXPECTED__
#4 budgerigar Gizmo            0.20 
#0 cat Pook             3.20 
#1 dog Peaches          12.30 
#5 goat Rickety Ride     9.70 
#3 gold fish Bubbles          0.10 
#2 horse Smarty           350.00 
#6 llama Sweater          150.00 
#
#Number of rows: 7
#__SYSTEMI_EXPECTED__
#4 budgerigar Gizmo            0.20 
#0 cat Pook             3.20 
#1 dog Peaches          12.30 
#5 goat Rickety Ride     9.70 
#3 gold fish Bubbles          0.10 
#2 horse Smarty           350.00 
#6 llama Sweater          150.00 
#
#Number of rows: 7
#__IDS_EXPECTED__
#4 budgerigar Gizmo            0.20 
#0 cat Pook             3.20 
#1 dog Peaches          12.30 
#5 goat Rickety Ride     9.70 
#3 gold fish Bubbles          0.10 
#2 horse Smarty           350.00 
#6 llama Sweater          150.00 
#
#Number of rows: 7



# 
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

import unittest, sys
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

  def test_040_FetchTuple(self):
    obj = IbmDbTestFunctions()
    obj.assert_expect(self.run_test_040)
  
  def run_test_040(self): 
    conn = ibm_db.connect(config.database, config.user, config.password)

    ibm_db.autocommit(conn, ibm_db.SQL_AUTOCOMMIT_OFF)
      
    # Drop the test table, in case it exists
    drop = 'DROP TABLE animals'
    try:
      result = ibm_db.exec_immediate(conn, drop)
    except:
      pass
      
    # Create the test table
    create = 'CREATE TABLE animals (id INTEGER, breed VARCHAR(32), name CHAR(16), weight DECIMAL(7,2))'
    result = ibm_db.exec_immediate(conn, create)
      
    insert = "INSERT INTO animals values (0, 'cat', 'Pook', 3.2)"
      
    ibm_db.exec_immediate(conn, insert)
      
    stmt = ibm_db.exec_immediate(conn, "select * from animals")
    
    onerow = ibm_db.fetch_tuple(stmt)
     
    for element in onerow:
      print element

    ibm_db.rollback(conn)

#__END__
#__LUW_EXPECTED__
#0
#cat
#Pook            
#3.20
#__ZOS_EXPECTED__
#0
#cat
#Pook            
#3.20
#__SYSTEMI_EXPECTED__
#0
#cat
#Pook            
#3.20
#__IDS_EXPECTED__
#0
#cat
#Pook            
#3.20



# 
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

import unittest, sys
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

  def test_091_ConnmsgWrongUser(self):
    obj = IbmDbTestFunctions()
    obj.assert_expect(self.run_test_091)

  def run_test_091(self):
    try:
      conn = ibm_db.connect(config.database, "y", config.password)
      print "??? No way."
    except:
      err = ibm_db.conn_errormsg()
      print err

#__END__
#__LUW_EXPECTED__
#[IBM][CLI Driver] SQL30082N  Security processing failed with reason "24" ("USERNAME AND/OR PASSWORD INVALID").  SQLSTATE=08001 SQLCODE=-30082
#__ZOS_EXPECTED__
#[IBM][CLI Driver] SQL30082N  Security processing failed with reason "15" ("PROCESSING FAILURE").  SQLSTATE=08001 SQLCODE=-30082
#__SYSTEMI_EXPECTED__
#[IBM][CLI Driver] SQL30082N  Security processing failed with reason "24" ("USERNAME AND/OR PASSWORD INVALID").  SQLSTATE=08001 SQLCODE=-30082
#__IDS_EXPECTED__
#[IBM][CLI Driver] SQL30082N  Security processing failed with reason "24" ("USERNAME AND/OR PASSWORD INVALID").  SQLSTATE=08001 SQLCODE=-30082



# 
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#
# NOTE: IDS requires that you pass the schema name (cannot pass None)

import unittest, sys
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

  def test_191_ColumnsTable_02(self):
    obj = IbmDbTestFunctions()
    obj.assert_expectf(self.run_test_191)

  def run_test_191(self):
    conn = ibm_db.connect(config.database, config.user, config.password)
    server = ibm_db.server_info( conn )

    if conn:
      if (server.DBMS_NAME[0:3] == 'IDS'):
        result = ibm_db.columns(conn,None,config.user,"emp_photo");    
      else:
        result = ibm_db.columns(conn,None,None,"EMP_PHOTO");    

      i = 0
      row = ibm_db.fetch_both(result)
      while ( row ):
        if (server.DBMS_NAME[0:3] == 'IDS'):
          if ( (row['column_name'] != 'emp_rowid') and (i < 3) ):
            print "%s,%s,%s,%s\n" % (row['table_schem'], 
            row['table_name'], row['column_name'], row['is_nullable'])
        else :
          if ( (row['COLUMN_NAME'] != 'EMP_ROWID') and (i < 3) ):
            print"%s,%s,%s,%s\n" % (row['TABLE_SCHEM'], 
            row['TABLE_NAME'], row['COLUMN_NAME'], row['IS_NULLABLE'])
        i = i + 1
        row = ibm_db.fetch_both(result)
      print "done!"
    else:
      print "no connection: ", ibm_db.conn_errormsg()    

#__END__
#__LUW_EXPECTED__
#%s,EMP_PHOTO,EMPNO,NO
#%s,EMP_PHOTO,PHOTO_FORMAT,NO
#%s,EMP_PHOTO,PICTURE,YES
#done!
#__ZOS_EXPECTED__
#%s,EMP_PHOTO,EMPNO,NO
#%s,EMP_PHOTO,PHOTO_FORMAT,NO
#%s,EMP_PHOTO,PICTURE,YES
#done!
#__SYSTEMI_EXPECTED__
#%s,EMP_PHOTO,EMPNO,NO
#%s,EMP_PHOTO,PHOTO_FORMAT,NO
#%s,EMP_PHOTO,PICTURE,YES
#done!
#__IDS_EXPECTED__
#%s,emp_photo,empno,NO
#%s,emp_photo,photo_format,NO
#%s,emp_photo,picture,YES
#done!



# 
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

import unittest, sys
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

  def test_200_MultipleRsltsetsUniformColDefs(self):
    obj = IbmDbTestFunctions()
    obj.assert_expect(self.run_test_200)

  def run_test_200(self):
    conn = ibm_db.connect(config.database, config.user, config.password)
    serverinfo = ibm_db.server_info( conn )
    server = serverinfo.DBMS_NAME[0:3]
    if (server == 'IDS'):
       procedure = """
        CREATE FUNCTION multiResults()
         RETURNING CHAR(16), INT;
                
         DEFINE p_name CHAR(16);
         DEFINE p_id INT;
               
         FOREACH c1 FOR
             SELECT name, id
              INTO p_name, p_id
               FROM animals
               ORDER BY name
              RETURN p_name, p_id WITH RESUME;
         END FOREACH;
                
       END FUNCTION;
       """
    else:
       procedure = """
        CREATE PROCEDURE multiResults ()
        RESULT SETS 3
        LANGUAGE SQL
        BEGIN
         DECLARE c1 CURSOR WITH RETURN FOR
          SELECT name, id
          FROM animals
          ORDER BY name;
    
         DECLARE c2 CURSOR WITH RETURN FOR
          SELECT name, id
          FROM animals
          WHERE id < 4
          ORDER BY name DESC;
    
         DECLARE c3 CURSOR WITH RETURN FOR
          SELECT name, id
          FROM animals
          WHERE weight < 5.0
          ORDER BY name;
    
         OPEN c1;
         OPEN c2;
         OPEN c3;
        END
       """
    
    if conn:
     try:
       ibm_db.exec_immediate(conn, 'DROP PROCEDURE multiResults')
     except:
       pass
     ibm_db.exec_immediate(conn, procedure)
     stmt = ibm_db.exec_immediate(conn, 'CALL multiResults()')
    
     print "Fetching first result set"
     row = ibm_db.fetch_tuple(stmt)
     while ( row ):
       for i in row:
         print i
       row = ibm_db.fetch_tuple(stmt)
    
     if (server == 'IDS'):
       print "Fetching second result set (should fail -- IDS does not support multiple result sets)"
     else:
       print "Fetching second result set"
     res = ibm_db.next_result (stmt)
     if res:
       row = ibm_db.fetch_tuple(res)
       while ( row ):
         for i in row:
           print i
         row = ibm_db.fetch_tuple(res)
    
     if (server == 'IDS'):
       print "Fetching third result set (should fail -- IDS does not support multiple result sets)"
     else:
       print "Fetching third result set"
     res2 = ibm_db.next_result(stmt)
     if res2:
       row = ibm_db.fetch_tuple(res2)
       while ( row ):
         for i in row:
           print i
         row = ibm_db.fetch_tuple(res2)
    
     print "Fetching fourth result set (should fail)"
     res3 = ibm_db.next_result(stmt)
     if res3:
       row = ibm_db.fetch_tuple(res3)
       while ( row ):
         for i in row:
           print i
         row = ibm_db.fetch_tuple(res3)
     
     ibm_db.close(conn)
    else:
      print "Connection failed."

#__END__
#__LUW_EXPECTED__
#Fetching first result set
#Bubbles         
#3
#Gizmo           
#4
#Peaches         
#1
#Pook            
#0
#Rickety Ride    
#5
#Smarty          
#2
#Sweater         
#6
#Fetching second result set
#Smarty          
#2
#Pook            
#0
#Peaches         
#1
#Bubbles         
#3
#Fetching third result set
#Bubbles         
#3
#Gizmo           
#4
#Pook            
#0
#Fetching fourth result set (should fail)
#__ZOS_EXPECTED__
#Fetching first result set
#Bubbles         
#3
#Gizmo           
#4
#Peaches         
#1
#Pook            
#0
#Rickety Ride    
#5
#Smarty          
#2
#Sweater         
#6
#Fetching second result set
#Smarty          
#2
#Pook            
#0
#Peaches         
#1
#Bubbles         
#3
#Fetching third result set
#Bubbles         
#3
#Gizmo           
#4
#Pook            
#0
#Fetching fourth result set (should fail)
#__SYSTEMI_EXPECTED__
#Fetching first result set
#Bubbles         
#3
#Gizmo           
#4
#Peaches         
#1
#Pook            
#0
#Rickety Ride    
#5
#Smarty          
#2
#Sweater         
#6
#Fetching second result set
#Smarty          
#2
#Pook            
#0
#Peaches         
#1
#Bubbles         
#3
#Fetching third result set
#Bubbles         
#3
#Gizmo           
#4
#Pook            
#0
#Fetching fourth result set (should fail)
#__IDS_EXPECTED__
#Fetching first result set
#Bubbles         
#3
#Gizmo           
#4
#Peaches         
#1
#Pook            
#0
#Rickety Ride    
#5
#Smarty          
#2
#Sweater         
#6
#Fetching second result set (should fail -- IDS does not support multiple result sets)
#Fetching third result set (should fail -- IDS does not support multiple result sets)
#Fetching fourth result set (should fail)



# 
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

import unittest, sys
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

  def test_070_Close(self):
    obj = IbmDbTestFunctions()
    obj.assert_expect(self.run_test_070)

  def run_test_070(self):
    conn = ibm_db.connect(config.database, config.user, config.password)
    
    if conn:
      if (type(conn) == ibm_db.IBM_DBConnection):
        print "Resource is a DB2 Connection"
      
      rc = ibm_db.close(conn)
      
      print rc
    else:
      print "Connection failed."

#__END__
#__LUW_EXPECTED__
#Resource is a DB2 Connection
#True
#__ZOS_EXPECTED__
#Resource is a DB2 Connection
#True
#__SYSTEMI_EXPECTED__
#Resource is a DB2 Connection
#True
#__IDS_EXPECTED__
#Resource is a DB2 Connection
#True



# 
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#
# NOTE: IDS requires that you pass the schema name (cannot pass None)

import unittest, sys
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

  def test_190_ColumnsTable_01(self):
    obj = IbmDbTestFunctions()
    obj.assert_expectf(self.run_test_190)

  def run_test_190(self):
    conn = ibm_db.connect(config.database, config.user, config.password)
    server = ibm_db.server_info( conn )

    if conn:
      if (server.DBMS_NAME[0:3] == 'IDS'):
        result = ibm_db.columns(conn,None,config.user,"employee")
      else:
        result = ibm_db.columns(conn,None,None,"EMPLOYEE")

      row = ibm_db.fetch_tuple(result)
      while ( row ):
        str = row[1] + "/" + row[3]
        print str
        row = ibm_db.fetch_tuple(result)
      print "done!"
    else:
      print "no connection:", ibm_db.conn_errormsg()

#__END__
#__LUW_EXPECTED__
#%s/EMPNO
#%s/FIRSTNME
#%s/MIDINIT
#%s/LASTNAME
#%s/WORKDEPT
#%s/PHONENO
#%s/HIREDATE
#%s/JOB
#%s/EDLEVEL
#%s/SEX
#%s/BIRTHDATE
#%s/SALARY
#%s/BONUS
#%s/COMM
#done!
#__ZOS_EXPECTED__
#%s/EMPNO
#%s/FIRSTNME
#%s/MIDINIT
#%s/LASTNAME
#%s/WORKDEPT
#%s/PHONENO
#%s/HIREDATE
#%s/JOB
#%s/EDLEVEL
#%s/SEX
#%s/BIRTHDATE
#%s/SALARY
#%s/BONUS
#%s/COMM
#done!
#__SYSTEMI_EXPECTED__
#%s/EMPNO
#%s/FIRSTNME
#%s/MIDINIT
#%s/LASTNAME
#%s/WORKDEPT
#%s/PHONENO
#%s/HIREDATE
#%s/JOB
#%s/EDLEVEL
#%s/SEX
#%s/BIRTHDATE
#%s/SALARY
#%s/BONUS
#%s/COMM
#done!
#__IDS_EXPECTED__
#%s/empno
#%s/firstnme
#%s/midinit
#%s/lastname
#%s/workdept
#%s/phoneno
#%s/hiredate
#%s/job
#%s/edlevel
#%s/sex
#%s/birthdate
#%s/salary
#%s/bonus
#%s/comm
#done!



# 
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

import unittest, sys
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

  def test_012_KeysetDrivenCursorSelect01(self):
    obj = IbmDbTestFunctions()
    obj.assert_expect(self.run_test_012)

  def run_test_012(self):
      conn = ibm_db.connect(config.database, config.user, config.password)
      
      if conn:
        serverinfo = ibm_db.server_info( conn )
        if (serverinfo.DBMS_NAME[0:3] != 'IDS'):
          stmt = ibm_db.prepare(conn, "SELECT name FROM animals WHERE weight < 10.0", {ibm_db.SQL_ATTR_CURSOR_TYPE: ibm_db.SQL_CURSOR_KEYSET_DRIVEN})
        else:
          stmt = ibm_db.prepare(conn, "SELECT name FROM animals WHERE weight < 10.0")
        ibm_db.execute(stmt)
        data = ibm_db.fetch_both( stmt )
        while (data):
          print data[0]
          data = ibm_db.fetch_both( stmt)
        ibm_db.close(conn)
      else:
        print "Connection failed."

#__END__
#__LUW_EXPECTED__
#Pook            
#Bubbles         
#Gizmo           
#Rickety Ride    
#__ZOS_EXPECTED__
#Pook            
#Bubbles         
#Gizmo           
#Rickety Ride    
#__SYSTEMI_EXPECTED__
#Pook            
#Bubbles         
#Gizmo           
#Rickety Ride    
#__IDS_EXPECTED__
#Pook            
#Bubbles         
#Gizmo           
#Rickety Ride    



# 
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

import unittest, sys
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

  def test_052_SetAutocommit_02(self):
    obj = IbmDbTestFunctions()
    obj.assert_expect(self.run_test_052)
	  
  def run_test_052(self):
    conn = ibm_db.connect(config.database, config.user, config.password)
      
    ibm_db.autocommit(conn, 0)
      
    ac = ibm_db.autocommit(conn)
      
    print ac

#__END__
#__LUW_EXPECTED__
#0
#__ZOS_EXPECTED__
#0
#__SYSTEMI_EXPECTED__
#0
#__IDS_EXPECTED__
#0



# 
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

import unittest, sys
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

  def test_113_DateTest(self):
    obj = IbmDbTestFunctions()
    obj.assert_expect(self.run_test_113)

  def run_test_113(self):
    conn = ibm_db.connect(config.database, config.user, config.password)
    
    if conn:
      drop = "DROP TABLE datetest"
      try:
        ibm_db.exec_immediate( conn, drop )
      except:
        pass
      
      create = "CREATE TABLE datetest ( id INTEGER, mydate DATE )"
      ibm_db.exec_immediate(conn, create)

      server = ibm_db.server_info( conn )
      if (server.DBMS_NAME[0:3] == 'IDS'):
        insert = "INSERT INTO datetest (id, mydate) VALUES (1,'1982-03-27')"
        ibm_db.exec_immediate(conn, insert)
        insert = "INSERT INTO datetest (id, mydate) VALUES (2,'1981-07-08')"
        ibm_db.exec_immediate(conn, insert)
      else:
        insert = "INSERT INTO datetest (id, mydate) VALUES (1,'1982-03-27')"
        ibm_db.exec_immediate(conn, insert)
        insert = "INSERT INTO datetest (id, mydate) VALUES (2,'1981-07-08')"
        ibm_db.exec_immediate(conn, insert)
      
      stmt = ibm_db.prepare(conn, "SELECT * FROM datetest")
      ibm_db.execute(stmt)

      result = ibm_db.fetch_row( stmt )
      while ( result ):
        row0 = ibm_db.result(stmt, 0)
        row1 = ibm_db.result(stmt, 1)
        print row0
        print row1
        result = ibm_db.fetch_row( stmt )
    else:
      print "Connection failed."

#__END__
#__LUW_EXPECTED__
#1
#1982-03-27
#2
#1981-07-08
#__ZOS_EXPECTED__
#1
#1982-03-27
#2
#1981-07-08
#__SYSTEMI_EXPECTED__
#1
#1982-03-27
#2
#1981-07-08
#__IDS_EXPECTED__
#1
#1982-03-27
#2
#1981-07-08



# 
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

import unittest, sys
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

  def test_066_TableObjects(self):
    obj = IbmDbTestFunctions()
    obj.assert_expectf(self.run_test_066)

  def run_test_066(self):
    conn = ibm_db.connect(config.database, config.user, config.password)
    server = ibm_db.server_info( conn )

    if (server.DBMS_NAME[0:3] == 'IDS'):
      result = ibm_db.tables(conn, None, config.user.lower(), 'animals')
    else:
      result = ibm_db.tables(conn, None, config.user.upper(), 'ANIMALS')
      
#    NOTE: This is a workaround
#    function fetch_object() to be implemented...
#    row = ibm_db.fetch_object(result)
    
    class Row:
        pass

    data = ibm_db.fetch_assoc(result)
    while ( data ):
      row = Row()
      if (server.DBMS_NAME[0:3] == 'IDS'):
        row.table_schem = data['table_schem']
        row.table_name = data['table_name']
        row.table_type = data['table_type']
        row.remarks = data['remarks']
          
        print "Schema:  %s" % row.table_schem
        print "Name:    %s" % row.table_name
        print "Type:    %s" % row.table_type
        print "Remarks: %s\n" % row.remarks
      else:
        row.TABLE_SCHEM = data['TABLE_SCHEM']
        row.TABLE_NAME = data['TABLE_NAME']
        row.TABLE_TYPE = data['TABLE_TYPE']
        row.REMARKS = data['REMARKS']
          
        print "Schema:  %s" % row.TABLE_SCHEM
        print "Name:    %s" % row.TABLE_NAME
        print "Type:    %s" % row.TABLE_TYPE
        print "Remarks: %s\n" % row.REMARKS
#      row = ibm_db.fetch_object(result)
      data = ibm_db.fetch_assoc(result)

    if (server.DBMS_NAME[0:3] == 'IDS'):
      result = ibm_db.tables(conn, None, config.user.lower(), 'animal_pics')
    else:
      result = ibm_db.tables(conn, None, config.user.upper(), 'ANIMAL_PICS')
    
#    row = ibm_db.fetch_object(result)
    data = ibm_db.fetch_assoc(result)
    while (data ):
      row = Row()
      if (server.DBMS_NAME[0:3] == 'IDS'):
        row.table_schem = data['table_schem']
        row.table_name = data['table_name']
        row.table_type = data['table_type']
        row.remarks = data['remarks']
        
        print "Schema:  %s" % row.table_schem
        print "Name:    %s" % row.table_name
        print "Type:    %s" % row.table_type
        print "Remarks: %s\n" % row.remarks
      else:
        row.TABLE_SCHEM = data['TABLE_SCHEM']
        row.TABLE_NAME = data['TABLE_NAME']
        row.TABLE_TYPE = data['TABLE_TYPE']
        row.REMARKS = data['REMARKS']
        
        print "Schema:  %s" % row.TABLE_SCHEM
        print "Name:    %s" % row.TABLE_NAME
        print "Type:    %s" % row.TABLE_TYPE
        print "Remarks: %s\n" % row.REMARKS
#      row = ibm_db.fetch_object(result)
      data = ibm_db.fetch_assoc(result)
      
    if (server.DBMS_NAME[0:3] == 'IDS'):
      result = ibm_db.tables(conn, None, config.user.lower(), 'anime_cat')
    else:
      result = ibm_db.tables(conn, None, config.user.upper(), 'ANIME_CAT')
    
#    row = ibm_db.fetch_object(result)
    data = ibm_db.fetch_assoc(result)
    while ( data ): 
      row = Row()
      if (server.DBMS_NAME[0:3] == 'IDS'):
        row.table_schem = data['table_schem']
        row.table_name = data['table_name']
        row.table_type = data['table_type']
        row.remarks = data['remarks']
        
        print "Schema:  %s" % row.table_schem
        print "Name:    %s" % row.table_name
        print "Type:    %s" % row.table_type
        print "Remarks: %s\n" % row.remarks
      else:
        row.TABLE_SCHEM = data['TABLE_SCHEM']
        row.TABLE_NAME = data['TABLE_NAME']
        row.TABLE_TYPE = data['TABLE_TYPE']
        row.REMARKS = data['REMARKS']
        
        print "Schema:  %s" % row.TABLE_SCHEM
        print "Name:    %s" % row.TABLE_NAME
        print "Type:    %s" % row.TABLE_TYPE
        print "Remarks: %s\n" % row.REMARKS
#      row = ibm_db.fetch_object(result)
      data = ibm_db.fetch_assoc(result)
    
    ibm_db.free_result(result)
    ibm_db.close(conn)

#__END__
#__LUW_EXPECTED__
#Schema:  %s
#Name:    ANIMALS
#Type:    TABLE
#Remarks: None
#
#Schema:  %s
#Name:    ANIMAL_PICS
#Type:    TABLE
#Remarks: None
#
#Schema:  %s
#Name:    ANIME_CAT
#Type:    VIEW
#Remarks: None
#__ZOS_EXPECTED__
#Schema:  %s
#Name:    ANIMALS
#Type:    TABLE
#Remarks: 
#
#Schema:  %s
#Name:    ANIMAL_PICS
#Type:    TABLE
#Remarks: 
#
#Schema:  %s
#Name:    ANIME_CAT
#Type:    VIEW
#Remarks: 
#__SYSTEMI_EXPECTED__
#Schema:  %s
#Name:    ANIMALS
#Type:    TABLE
#Remarks: None
#
#Schema:  %s
#Name:    ANIMAL_PICS
#Type:    TABLE
#Remarks: None
#
#Schema:  %s
#Name:    ANIME_CAT
#Type:    VIEW
#Remarks: None
#__IDS_EXPECTED__
#Schema:  %s
#Name:    animals
#Type:    TABLE
#Remarks: None
#
#Schema:  %s
#Name:    animal_pics
#Type:    TABLE
#Remarks: None
#
#Schema:  %s
#Name:    anime_cat
#Type:    VIEW
#Remarks: None



#
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

import unittest, sys
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

  def test_054_CursorType(self):
    obj = IbmDbTestFunctions()
    obj.assert_expect(self.run_test_054)

  def run_test_054(self):
    conn = ibm_db.connect(config.database, config.user, config.password)
    serverinfo = ibm_db.server_info( conn )

    stmt = ibm_db.exec_immediate(conn, "SELECT * FROM animals")
    val = ibm_db.get_option(stmt, ibm_db.SQL_ATTR_CURSOR_TYPE, 0)
    print val

    op = {ibm_db.SQL_ATTR_CURSOR_TYPE: ibm_db.SQL_CURSOR_FORWARD_ONLY}
    stmt = ibm_db.exec_immediate(conn, "SELECT * FROM animals", op)
    val = ibm_db.get_option(stmt, ibm_db.SQL_ATTR_CURSOR_TYPE, 0)
    print val

    if (serverinfo.DBMS_NAME[0:3] != 'IDS'):
      op = {ibm_db.SQL_ATTR_CURSOR_TYPE: ibm_db.SQL_CURSOR_KEYSET_DRIVEN}
    else:
      op = {ibm_db.SQL_ATTR_CURSOR_TYPE: ibm_db.SQL_CURSOR_STATIC}
    stmt = ibm_db.exec_immediate(conn, "SELECT * FROM animals", op)
    val = ibm_db.get_option(stmt, ibm_db.SQL_ATTR_CURSOR_TYPE, 0)
    print val

    op = {ibm_db.SQL_ATTR_CURSOR_TYPE: ibm_db.SQL_CURSOR_STATIC}
    stmt = ibm_db.exec_immediate(conn, "SELECT * FROM animals", op)
    val = ibm_db.get_option(stmt, ibm_db.SQL_ATTR_CURSOR_TYPE, 0)
    print val

#__END__
#__LUW_EXPECTED__
#0
#0
#1
#3
#__ZOS_EXPECTED__
#0
#0
#1
#3
#__SYSTEMI_EXPECTED__
#0
#0
#3
#3
#__IDS_EXPECTED__
#0
#0
#3
#3
#



# 
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

import unittest, sys
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

  def test_116_ConnActive(self):
    obj = IbmDbTestFunctions()
    obj.assert_expect(self.run_test_116)

  def run_test_116(self):
    conn = None
    is_alive = ibm_db.active(conn)
    if is_alive:
      print "Is active"
    else:
      print "Is not active"

    conn = ibm_db.connect(config.database, config.user, config.password)
    is_alive = ibm_db.active(conn)
    if is_alive:
      print "Is active"
    else:
      print "Is not active"

    ibm_db.close(conn)
    is_alive = ibm_db.active(conn)
    if is_alive:
      print "Is active"
    else:
      print "Is not active"

    # Executing active method multiple times to reproduce a customer reported defect
    print ibm_db.active(conn)
    print ibm_db.active(conn)
    print ibm_db.active(conn)
    conn = ibm_db.connect(config.database, config.user, config.password)
    print ibm_db.active(conn)
    print ibm_db.active(conn)
    print ibm_db.active(conn)

#__END__
#__LUW_EXPECTED__
#Is not active
#Is active
#Is not active
#False
#False
#False
#True
#True
#True
#__ZOS_EXPECTED__
#Is not active
#Is active
#Is not active
#False
#False
#False
#True
#True
#True
#__SYSTEMI_EXPECTED__
#Is not active
#Is active
#Is not active
#False
#False
#False
#True
#True
#True
#__IDS_EXPECTED__
#Is not active
#Is active
#Is not active
#False
#False
#False
#True
#True
#True



# 
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

import unittest, sys
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

  def test_051_SetAutocommit_01(self):
    obj = IbmDbTestFunctions()
    obj.assert_expect(self.run_test_051)

  def run_test_051(self):
    options = { ibm_db.SQL_ATTR_AUTOCOMMIT:  ibm_db.SQL_AUTOCOMMIT_OFF }
      
    conn = ibm_db.connect(config.database, config.user, config.password, options)
      
    ac = ibm_db.autocommit(conn)
      
    print ac

#__END__
#__LUW_EXPECTED__
#0
#__ZOS_EXPECTED__
#0
#__SYSTEMI_EXPECTED__
#0
#__IDS_EXPECTED__
#0
